<?php
/* Copyright (C) 2001-2005 Rodolphe Quiedeville <rodolphe@quiedeville.org>
 * Copyright (C) 2004-2015 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2005-2012 Regis Houssin        <regis.houssin@inodbox.com>
 * Copyright (C) 2015      Jean-François Ferry	<jfefe@aternatik.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

/**
 *    \file       advancedpos/cashcontrol_stat.php
 *    \ingroup    advancedpos
 *    \brief      Home page of advancedpos top menu
 */

// Load Dolibarr environment
$res = 0;
// Try main.inc.php into web root known defined into CONTEXT_DOCUMENT_ROOT (not always defined)
if (!$res && !empty($_SERVER["CONTEXT_DOCUMENT_ROOT"])) {
    $res = @include $_SERVER["CONTEXT_DOCUMENT_ROOT"] . "/main.inc.php";
}
// Try main.inc.php into web root detected using web root calculated from SCRIPT_FILENAME
$tmp = empty($_SERVER['SCRIPT_FILENAME']) ? '' : $_SERVER['SCRIPT_FILENAME'];
$tmp2 = realpath(__FILE__);
$i = strlen($tmp) - 1;
$j = strlen($tmp2) - 1;
while ($i > 0 && $j > 0 && isset($tmp[$i]) && isset($tmp2[$j]) && $tmp[$i] == $tmp2[$j]) {
    $i--;
    $j--;
}
if (!$res && $i > 0 && file_exists(substr($tmp, 0, ($i + 1)) . "/main.inc.php")) {
    $res = @include substr($tmp, 0, ($i + 1)) . "/main.inc.php";
}
if (!$res && $i > 0 && file_exists(dirname(substr($tmp, 0, ($i + 1))) . "/main.inc.php")) {
    $res = @include dirname(substr($tmp, 0, ($i + 1))) . "/main.inc.php";
}
// Try main.inc.php using relative path
if (!$res && file_exists("../main.inc.php")) {
    $res = @include "../main.inc.php";
}
if (!$res && file_exists("../../main.inc.php")) {
    $res = @include "../../main.inc.php";
}
if (!$res && file_exists("../../../main.inc.php")) {
    $res = @include "../../../main.inc.php";
}
if (!$res) {
    die("Include of main fails");
}

require_once DOL_DOCUMENT_ROOT . '/core/class/html.formfile.class.php';

global $user, $langs;

// Load translation files required by the page
$langs->loadLangs(array("advancedpos@advancedpos"));

$action = GETPOST('action', 'aZ09');
$socid = GETPOST('socid', 'int');


// Security check
if (empty($conf->takepos->enabled)) accessforbidden('Module not enabled');
if ($user->socid > 0)    // Protection if external user
{
    accessforbidden();
}
if (isset($user->socid) && $user->socid > 0) {
    $action = '';
    $socid = $user->socid;
}

$max = 5;
$now = dol_now();


/*
 * Actions
 */
global $hookmanager,$db;
$action = GETPOST('action', 'aZ09') ? GETPOST('action', 'aZ09') : 'view'; // The action 'add', 'create', 'edit', 'update', 'view', ...
$show_files = GETPOST('show_files', 'int'); // Show files area generated by bulk actions ?
$confirm = GETPOST('confirm', 'alpha'); // Result of a confirmation
$cancel = GETPOST('cancel', 'alpha'); // We click on a Cancel button
$toselect = GETPOST('toselect', 'array'); // Array of ids of elements selected into a list
$contextpage = GETPOST('contextpage', 'aZ') ? GETPOST('contextpage', 'aZ') : 'equipmentlist'; // To manage different context of search
$backtopage = GETPOST('backtopage', 'alpha'); // Go back to a dedicated page
$optioncss = GETPOST('optioncss', 'aZ'); // Option for the css output (always '' except when 'print')
$limit = GETPOST('limit', 'int') ? GETPOST('limit', 'int') : $conf->liste_limit;
$sortfield = GETPOST('sortfield', 'alpha');
$sortorder = GETPOST('sortorder', 'alpha');
$page = GETPOST('page', 'int');
if (empty($page) || $page == -1 || GETPOST('button_search', 'alpha') || GETPOST('button_removefilter', 'alpha')) {
    $page = 0;
}     // If $page is not defined, or '' or -1 or if we click on clear filters or if we select empty mass action
$offset = $limit * $page;
$pageprev = $page - 1;
$pagenext = $page + 1;

$object = new stdClass();
$object->fields = array(
    'refFacture' => array('type' => 'varchar(128)', 'label' => 'RefFacture', 'enabled' => 1, 'position' => 10, 'notnull' => 1, 'visible' => 4, 'noteditable' => '1', 'default' => '(PROV)', 'index' => 1, 'searchall' => 1, 'showoncombobox' => '1', 'comment' => "Reference of object"),
    'refProduit' => array('type' => 'varchar(128)', 'label' => 'RefProduit', 'enabled' => 1, 'position' => 10, 'notnull' => 1, 'visible' => 1, 'index' => 1,),
    'Terminal' => array('type' => 'integer', 'label' => 'Terminal', 'enabled' => 1, 'position' => 32, 'notnull' => 0, 'visible' => 1, 'index' => 1,),
    'Categ' => array('type' => 'integer', 'label' => 'CategProduit', 'enabled' => 1, 'position' => 50, 'notnull' => -1, 'visible' => 1, 'index' => 1, 'css' => 'maxwidth500', 'help' => "LinkToThirparty",),
    'qty' => array('type' => 'integer', 'label' => 'qtyProduit', 'enabled' => 1, 'position' => 50, 'notnull' => -1, 'visible' => 1, 'index' => 1, 'css' => 'maxwidth500', 'help' => "LinkToThirparty",),
    'date_start' => array('type' => 'date', 'label' => 'date_start', 'enabled' => 1, 'position' => 35, 'notnull' => 0, 'visible' => 1, 'css' => 'minwidth200', 'showoncombobox' => '1',),
    'date_end' => array('type' => 'date', 'label' => 'date_end', 'enabled' => 1, 'position' => 35, 'notnull' => 0, 'visible' => 1, 'css' => 'minwidth200', 'showoncombobox' => '1',),
    'total_tva' => array('type' => 'double(22,2)', 'label' => 'total_tva', 'enabled' => 1, 'position' => 62, 'notnull' => 0, 'visible' => -1,),
    'tva_tx' => array('type' => 'double(22,2)', 'label' => 'TXTVA', 'enabled' => 1, 'position' => 62, 'notnull' => 0, 'visible' => -1,),
    'total_ttc' => array('type' => 'double(22,2)', 'label' => 'total_ttc', 'enabled' => 1, 'position' => 500, 'notnull' => 1, 'visible' => -2,),
    'total_ht' => array('type' => 'double(22,2)', 'label' => 'total_ht', 'enabled' => 1, 'position' => 501, 'notnull' => 0, 'visible' => -2,),
);

$hookmanager->initHooks(array('cashcontrol_stat')); // Note that conf->hooks_modules contains array
// Default sort order (if not yet defined by previous GETPOST)
if (!$sortfield) $sortfield = "t." . key($object->fields); // Set here default search field. By default 1st field in definition.
if (!$sortorder) $sortorder = "ASC";
$search_all = trim(GETPOST("search_all", 'alpha'));
$search = array();
foreach ($object->fields as $key => $val) {
    if (GETPOST('search_' . $key, 'alpha') !== '') $search[$key] = GETPOST('search_' . $key, 'alpha');
}
// List of fields to search into when doing a "search in all"
$fieldstosearchall = array();
foreach ($object->fields as $key => $val) {
    if ($val['searchall']) $fieldstosearchall['t.' . $key] = $val['label'];
}

// Definition of fields for list
$arrayfields = array();
foreach ($object->fields as $key => $val) {
    // If $val['visible']==0, then we never show the field
    if (!empty($val['visible'])) $arrayfields['t.' . $key] = array('label' => $val['label'], 'checked' => (($val['visible'] < 0) ? 0 : 1), 'enabled' => ($val['enabled'] && ($val['visible'] != 3)), 'position' => $val['position']);
}
$object->fields = dol_sort_array($object->fields, 'position');


$parameters = array();
$reshook = $hookmanager->executeHooks('doActions', $parameters, $object, $action); // Note that $action and $object may have been modified by some hooks
if ($reshook < 0) setEventMessages($hookmanager->error, $hookmanager->errors, 'errors');
if (empty($reshook)) {
    include DOL_DOCUMENT_ROOT . '/core/actions_changeselectedfields.inc.php';

    // Purge search criteria
    if (GETPOST('button_removefilter_x', 'alpha') || GETPOST('button_removefilter.x', 'alpha') || GETPOST('button_removefilter', 'alpha')) // All tests are required to be compatible with all browsers
    {
        foreach ($object->fields as $key => $val) {
            $search[$key] = '';
        }
        $toselect = '';
        $search_array_options = array();
    }
    if (GETPOST('button_removefilter_x', 'alpha') || GETPOST('button_removefilter.x', 'alpha') || GETPOST('button_removefilter', 'alpha')
        || GETPOST('button_search_x', 'alpha') || GETPOST('button_search.x', 'alpha') || GETPOST('button_search', 'alpha')) {
    }
}

$now = dol_now();
llxHeader("", $langs->trans("Stat_AdvancedPos"));

print load_fiche_titre($langs->trans("Stat_AdvancedPos"), '', 'advancedpos.png@advancedpos');

print info_admin($langs->trans("WarningStat"), 0, 0, 'warning');

require_once DOL_DOCUMENT_ROOT.'/core/class/html.formfile.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/html.formother.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/html.formcompany.class.php';
if (!empty($conf->margin->enabled)) {
    require_once DOL_DOCUMENT_ROOT.'/core/class/html.formmargin.class.php';
}
require_once DOL_DOCUMENT_ROOT.'/core/modules/facture/modules_facture.php';
require_once DOL_DOCUMENT_ROOT.'/compta/bank/class/account.class.php';
require_once DOL_DOCUMENT_ROOT.'/compta/facture/class/facture.class.php';
require_once DOL_DOCUMENT_ROOT.'/product/class/product.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/discount.class.php';
require_once DOL_DOCUMENT_ROOT.'/compta/paiement/class/paiement.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/functions2.lib.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/invoice.lib.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/date.lib.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/company.lib.php';


$sall = trim((GETPOST('search_all', 'alphanohtml') != '') ?GETPOST('search_all', 'alphanohtml') : GETPOST('sall', 'alphanohtml'));

$id = (GETPOST('id', 'int') ?GETPOST('id', 'int') : GETPOST('facid', 'int')); // For backward compatibility
$ref = GETPOST('ref', 'alpha');
$socid = GETPOST('socid', 'int');

$action = GETPOST('action', 'aZ09');
$show_files = GETPOST('show_files', 'int');
$confirm = GETPOST('confirm', 'alpha');
$toselect = GETPOST('toselect', 'array');
$contextpage = GETPOST('contextpage', 'aZ') ?GETPOST('contextpage', 'aZ') : 'invoicelist';

if ($contextpage == 'poslist') {
    $_GET['optioncss'] = 'print';
}

$lineid = GETPOST('lineid', 'int');
$search_tva_tx = GETPOST('search_tva_tx', 'int');
$search_product_qty = GETPOST('search_product_qty', 'int');
$search_product_category = GETPOST('search_product_category', 'int');
$search_ref = GETPOST('sf_ref') ?GETPOST('sf_ref', 'alpha') : GETPOST('search_ref', 'alpha');
$search_type = GETPOST('search_type', 'int');
$search_montant_ht = GETPOST('search_montant_ht', 'alpha');
$search_montant_vat = GETPOST('search_montant_vat', 'alpha');
$search_montant_ttc = GETPOST('search_montant_ttc', 'alpha');
$search_multicurrency_code = GETPOST('search_multicurrency_code', 'alpha');
$search_multicurrency_tx = GETPOST('search_multicurrency_tx', 'alpha');
$search_multicurrency_montant_ht = GETPOST('search_multicurrency_montant_ht', 'alpha');
$search_multicurrency_montant_vat = GETPOST('search_multicurrency_montant_vat', 'alpha');
$search_multicurrency_montant_ttc = GETPOST('search_multicurrency_montant_ttc', 'alpha');
$search_status = GETPOST('search_status', 'intcomma');
$search_paymentmode = GETPOST('search_paymentmode', 'int');
$search_paymentterms = GETPOST('search_paymentterms', 'int');
$search_pos_source = GETPOST('search_pos_source', 'alpha');
$search_date_startday = GETPOST('search_date_startday', 'int');
$search_date_startmonth = GETPOST('search_date_startmonth', 'int');
$search_date_startyear = GETPOST('search_date_startyear', 'int');
$search_date_endday = GETPOST('search_date_endday', 'int');
$search_date_endmonth = GETPOST('search_date_endmonth', 'int');
$search_date_endyear = GETPOST('search_date_endyear', 'int');
$search_date_start = dol_mktime(0, 0, 0, $search_date_startmonth, $search_date_startday, $search_date_startyear); // Use tzserver
$search_date_end = dol_mktime(23, 59, 59, $search_date_endmonth, $search_date_endday, $search_date_endyear);
$search_date_valid_startday = GETPOST('search_date_valid_startday', 'int');
$search_date_valid_startmonth = GETPOST('search_date_valid_startmonth', 'int');
$search_date_valid_startyear = GETPOST('search_date_valid_startyear', 'int');
$search_date_valid_endday = GETPOST('search_date_valid_endday', 'int');
$search_date_valid_endmonth = GETPOST('search_date_valid_endmonth', 'int');
$search_date_valid_endyear = GETPOST('search_date_valid_endyear', 'int');
$search_date_valid_start = dol_mktime(0, 0, 0, $search_date_valid_startmonth, $search_date_valid_startday, $search_date_valid_startyear); // Use tzserver
$search_date_valid_end = dol_mktime(23, 59, 59, $search_date_valid_endmonth, $search_date_valid_endday, $search_date_valid_endyear);
$search_datelimit_startday = GETPOST('search_datelimit_startday', 'int');
$search_datelimit_startmonth = GETPOST('search_datelimit_startmonth', 'int');
$search_datelimit_startyear = GETPOST('search_datelimit_startyear', 'int');
$search_datelimit_endday = GETPOST('search_datelimit_endday', 'int');
$search_datelimit_endmonth = GETPOST('search_datelimit_endmonth', 'int');
$search_datelimit_endyear = GETPOST('search_datelimit_endyear', 'int');
$search_datelimit_start = dol_mktime(0, 0, 0, $search_datelimit_startmonth, $search_datelimit_startday, $search_datelimit_startyear);
$search_datelimit_end = dol_mktime(23, 59, 59, $search_datelimit_endmonth, $search_datelimit_endday, $search_datelimit_endyear);
$search_categ_cus = GETPOST("search_categ_cus", 'int');
$search_btn = GETPOST('button_search', 'alpha');
$search_remove_btn = GETPOST('button_removefilter', 'alpha');
$search_refProduct = GETPOST('search_refProduct', 'alpha');
$option = GETPOST('search_option');
$filtre = GETPOST('filtre', 'alpha');
$limit = GETPOST('limit', 'int') ?GETPOST('limit', 'int') : $conf->liste_limit;
$sortfield = GETPOST('sortfield', 'aZ09comma');
$sortorder = GETPOST('sortorder', 'aZ09comma');
$page = GETPOSTISSET('pageplusone') ? (GETPOST('pageplusone') - 1) : GETPOST("page", 'int');
if (empty($page) || $page < 0 || GETPOST('button_search', 'alpha') || GETPOST('button_removefilter', 'alpha')) {
    $page = 0;
}     // If $page is not defined, or '' or -1 or if we click on clear filters
$offset = $limit * $page;
if (!$sortorder && !empty($conf->global->INVOICE_DEFAULT_UNPAYED_SORT_ORDER) && $search_status == '1') {
    $sortorder = $conf->global->INVOICE_DEFAULT_UNPAYED_SORT_ORDER;
}
if (!$sortorder) {
    $sortorder = 'DESC';
}
if (!$sortfield) {
    $sortfield = 'f.datef';
}
$pageprev = $page - 1;
$pagenext = $page + 1;

// Security check
$fieldid = (!empty($ref) ? 'ref' : 'rowid');
if (!empty($user->socid)) {
    $socid = $user->socid;
}


$object = new Facture($db);
$object_product = new Product($db);

$now = dol_now();
$error = 0;

// Initialize technical object to manage hooks of page. Note that conf->hooks_modules contains array of hook context
$hookmanager->initHooks(array('cashcontrol_statlist'));
$extrafields = new ExtraFields($db);

// fetch optionals attributes and labels
$extrafields->fetch_name_optionals_label($object->table_element);

$search_array_options = $extrafields->getOptionalsFromPost($object->table_element, '', 'search_');

// List of fields to search into when doing a "search in all"
$fieldstosearchall = array(
    'f.ref'=>'Ref',
    'f.ref_client'=>'RefCustomer',
    'pd.description'=>'Description',
    's.nom'=>"ThirdParty",
    's.name_alias'=>"AliasNameShort",
    's.zip'=>"Zip",
    's.town'=>"Town",
    'f.note_public'=>'NotePublic',
);
$checkedtypetiers = 0;
$arrayfields = array(
    'p.ref'=>array('label'=>"RefProduit", 'checked'=>1, 'position'=>2),
    'f.ref'=>array('label'=>"Ref", 'checked'=>1, 'position'=>5),
    'f.ref_client'=>array('label'=>"RefCustomer", 'checked'=>-1, 'position'=>10),
    'f.type'=>array('label'=>"Type", 'checked'=>0, 'position'=>15),
    'f.datef'=>array('label'=>"DateInvoice", 'checked'=>1, 'position'=>20),
    'f.fk_mode_reglement'=>array('label'=>"PaymentMode", 'checked'=>1, 'position'=>80),
    'f.fk_cond_reglement'=>array('label'=>"PaymentConditionsShort", 'checked'=>1, 'position'=>85),
    'f.module_source'=>array('label'=>"POSModule", 'checked'=>($contextpage == 'poslist' ? 1 : 0), 'enabled'=>((empty($conf->cashdesk->enabled) && empty($conf->takepos->enabled) && empty($conf->global->INVOICE_SHOW_POS)) ? 0 : 1), 'position'=>90),
    'f.pos_source'=>array('label'=>"POSTerminal", 'checked'=>($contextpage == 'poslist' ? 1 : 0), 'enabled'=>((empty($conf->cashdesk->enabled) && empty($conf->takepos->enabled) && empty($conf->global->INVOICE_SHOW_POS)) ? 0 : 1), 'position'=>91),
    'pd.total_ht'=>array('label'=>"AmountHT", 'checked'=>1, 'position'=>95),
    'pd.total_tva'=>array('label'=>"AmountVAT", 'checked'=>1, 'position'=>100),
    'pd.qty'=>array('label'=>"product_qty", 'checked'=>1, 'position'=>100),
    'pd.tva_tx'=>array('label'=>"TXTVA", 'checked'=>1, 'position'=>100),
    'pd.total_ttc'=>array('label'=>"AmountTTC", 'checked'=>1, 'position'=>130),
    'f.fk_statut'=>array('label'=>"Status", 'checked'=>1, 'position'=>1000),
);


$arrayfields = dol_sort_array($arrayfields, 'position');


/*
 * Actions
 */



$parameters = array('socid'=>$socid);
$reshook = $hookmanager->executeHooks('doActions', $parameters, $object, $action); // Note that $action and $object may have been modified by some hooks
if ($reshook < 0) {
    setEventMessages($hookmanager->error, $hookmanager->errors, 'errors');
}

include DOL_DOCUMENT_ROOT.'/core/actions_changeselectedfields.inc.php';

// Do we click on purge search criteria ?
if (GETPOST('button_removefilter_x', 'alpha') || GETPOST('button_removefilter', 'alpha') || GETPOST('button_removefilter.x', 'alpha')) { // All tests are required to be compatible with all browsers
    $search_product_category = '';
    $search_ref = '';
    $search_type = '';
    $search_montant_ht = '';
    $search_montant_vat = '';
    $search_montant_ttc = '';
    $search_status = '';
    $search_paymentmode = '';
    $search_paymentterms = '';
    $search_module_source = '';
    $search_pos_source = '';
    $search_date_startday = '';
    $search_date_startmonth = '';
    $search_date_startyear = '';
    $search_date_endday = '';
    $search_date_endmonth = '';
    $search_date_endyear = '';
    $search_date_start = '';
    $search_date_end = '';
    $option = '';
    $filter = '';
    $search_refProduct = '';
    $toselect = '';
    $search_array_options = array();
    $search_categ_cus = 0;
    $search_tva_tx = "";
    $search_product_qty = "";
}


if ($action == 'makepayment_confirm' && !empty($user->rights->facture->paiement)) {
    require_once DOL_DOCUMENT_ROOT.'/compta/paiement/class/paiement.class.php';
    $arrayofselected = is_array($toselect) ? $toselect : array();
    if (!empty($arrayofselected)) {
        $bankid = GETPOST('bankid', 'int');
        $paiementid = GETPOST('paiementid', 'int');
        $paiementdate = dol_mktime(12, 0, 0, GETPOST('datepaimentmonth', 'int'), GETPOST('datepaimentday', 'int'), GETPOST('datepaimentyear', 'year'));
        if (empty($paiementdate)) {
            setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv("Date")), null, 'errors');
            $error++;
            $action = 'makepayment';
        }

        if (!$error) {
            foreach ($arrayofselected as $toselectid) {
                $errorpayment = 0;
                $facture = new Facture($db);
                $result = $facture->fetch($toselectid);

                $db->begin();

                if ($result < 0) {
                    setEventMessage($facture->error, 'errors');
                    $errorpayment++;
                } else {
                    if ($facture->type != Facture::TYPE_CREDIT_NOTE && $facture->statut == Facture::STATUS_VALIDATED && $facture->paye == 0) {
                        $paiementAmount = $facture->getSommePaiement();
                        $totalcreditnotes = $facture->getSumCreditNotesUsed();
                        $totaldeposits = $facture->getSumDepositsUsed();
                        $totalpay = $paiementAmount + $totalcreditnotes + $totaldeposits;
                        $remaintopay = price2num($facture->total_ttc - $totalpay);
                        if ($remaintopay != 0) {
                            $resultBank = $facture->setBankAccount($bankid);
                            if ($resultBank < 0) {
                                setEventMessages($facture->error, null, 'errors');
                                $errorpayment++;
                            } else {
                                $paiement = new Paiement($db);
                                $paiement->datepaye = $paiementdate;
                                $paiement->amounts[$facture->id] = $remaintopay; // Array with all payments dispatching with invoice id
                                $paiement->multicurrency_amounts[$facture->id] = $remaintopay;
                                $paiement->paiementid = $paiementid;
                                $paiement_id = $paiement->create($user, 1, $facture->thirdparty);
                                if ($paiement_id < 0) {
                                    $langs->load("errors");
                                    setEventMessages($facture->ref.' '.$langs->trans($paiement->error), $paiement->errors, 'errors');
                                    $errorpayment++;
                                } else {
                                    $result = $paiement->addPaymentToBank($user, 'payment', '', $bankid, '', '');
                                    if ($result < 0) {
                                        $langs->load("errors");
                                        setEventMessages($facture->ref.' '.$langs->trans($paiement->error), $paiement->errors, 'errors');
                                        $errorpayment++;
                                    }
                                }
                            }
                        } else {
                            setEventMessage($langs->trans('NoPaymentAvailable', $facture->ref), 'warnings');
                            $errorpayment++;
                        }
                    } else {
                        setEventMessage($langs->trans('BulkPaymentNotPossibleForInvoice', $facture->ref), 'warnings');
                        $errorpayment++;
                    }
                }

                if (empty($errorpayment)) {
                    setEventMessage($langs->trans('PaymentRegisteredAndInvoiceSetToPaid', $facture->ref));
                    $db->commit();
                } else {
                    $db->rollback();
                }
            }
        }
    }
}



/*
 * View
 */

$form = new Form($db);
$formother = new FormOther($db);
$formfile = new FormFile($db);
$bankaccountstatic = new Account($db);
$facturestatic = new Facture($db);
$formcompany = new FormCompany($db);
$companystatic = new Societe($db);

$sql = 'SELECT';
$sql .= ' f.rowid as id, f.ref, f.ref_client, f.fk_soc, f.type, f.note_private, f.note_public, f.increment, f.fk_mode_reglement, f.fk_cond_reglement, pd.total_ht, pd.total_tva,pd.qty, pd.total_ttc, pd.tva_tx, ';
$sql .= ' f.fk_user_author,';
$sql .= ' f.datef, f.date_valid, f.date_lim_reglement as datelimite, f.module_source, f.pos_source,';
$sql .= ' f.paye as paye, f.fk_statut, f.close_code,';
$sql .= ' f.datec as date_creation, f.tms as date_update, f.date_closing as date_closing,';
$sql .= ' f.retained_warranty, f.retained_warranty_date_limit, f.situation_final, f.situation_cycle_ref, f.situation_counter,';
$sql .= ' s.rowid as socid, s.nom as name, s.name_alias as alias, s.email, s.phone, s.fax, s.address, s.town, s.zip, s.fk_pays, s.client, s.fournisseur, s.code_client, s.code_fournisseur, s.code_compta as code_compta_client, s.code_compta_fournisseur,';
$sql .= ' typent.code as typent_code,';
$sql .= ' state.code_departement as state_code, state.nom as state_name,';
$sql .= ' p.rowid as product_id, p.ref as product_ref, ';
$sql .= ' u.login, u.lastname, u.firstname, u.email as user_email, u.statut as user_statut, u.entity, u.photo, u.office_phone, u.office_fax, u.user_mobile, u.job, u.gender';
// We need dynamount_payed to be able to sort on status (value is surely wrong because we can count several lines several times due to other left join or link with contacts. But what we need is just 0 or > 0)
if (!$sall) {
    $sql .= ', SUM(pf.amount) as dynamount_payed, SUM(pf.multicurrency_amount) as multicurrency_dynamount_payed';
}
if ($search_categ_cus && $search_categ_cus != -1) {
    $sql .= ", cc.fk_categorie, cc.fk_soc";
}
// Add fields from extrafields
if (!empty($extrafields->attributes[$object->table_element]['label'])) {
    foreach ($extrafields->attributes[$object->table_element]['label'] as $key => $val) {
        $sql .= ($extrafields->attributes[$object->table_element]['type'][$key] != 'separate' ? ", ef.".$key." as options_".$key : '');
    }
}
// Add fields from hooks
$parameters = array();
$reshook = $hookmanager->executeHooks('printFieldListSelect', $parameters); // Note that $action and $object may have been modified by hook
$sql .= $hookmanager->resPrint;
$sql .= ' FROM '.MAIN_DB_PREFIX.'societe as s';
$sql .= " LEFT JOIN ".MAIN_DB_PREFIX."c_country as country on (country.rowid = s.fk_pays)";
$sql .= " LEFT JOIN ".MAIN_DB_PREFIX."c_typent as typent on (typent.id = s.fk_typent)";
$sql .= " LEFT JOIN ".MAIN_DB_PREFIX."c_departements as state on (state.rowid = s.fk_departement)";
if (!empty($search_categ_cus) && $search_categ_cus != '-1') {
    $sql .= ' LEFT JOIN '.MAIN_DB_PREFIX."categorie_societe as cc ON s.rowid = cc.fk_soc"; // We'll need this table joined to the select in order to filter by categ
}

$sql .= ', '.MAIN_DB_PREFIX.'facture as f';
if (is_array($extrafields->attributes[$object->table_element]['label']) && count($extrafields->attributes[$object->table_element]['label'])) {
    $sql .= " LEFT JOIN ".MAIN_DB_PREFIX.$object->table_element."_extrafields as ef on (f.rowid = ef.fk_object)";
}
if (!$sall) {
    $sql .= ' LEFT JOIN '.MAIN_DB_PREFIX.'paiement_facture as pf ON pf.fk_facture = f.rowid';
}
$sql .= ' LEFT JOIN '.MAIN_DB_PREFIX.'facturedet as pd ON f.rowid=pd.fk_facture';
$sql .= ' LEFT JOIN '.MAIN_DB_PREFIX.'product as p ON pd.fk_product=p.rowid';
$sql .= ' LEFT JOIN '.MAIN_DB_PREFIX.'categorie_product as cp ON cp.fk_product=pd.fk_product';
$sql .= ' LEFT JOIN '.MAIN_DB_PREFIX.'user AS u ON f.fk_user_author = u.rowid';
// Add table from hooks
$parameters = array();
$reshook = $hookmanager->executeHooks('printFieldListFrom', $parameters, $object); // Note that $action and $object may have been modified by hook
$sql .= $hookmanager->resPrint;

$sql .= ' WHERE f.fk_soc = s.rowid';
$sql .= ' AND f.entity IN ('.getEntity('invoice').')';
if (empty($user->rights->societe->client->voir) && !$socid) {
    $sql .= " AND s.rowid = sc.fk_soc AND sc.fk_user = ".((int) $user->id);
}
if ($search_product_category > 0) {
    $sql .= " AND cp.fk_categorie = ".((int) $search_product_category);
}
if ($search_refProduct > 0){
    $sql .= " AND p.rowid  = ".((int) $search_refProduct);
}
if ($socid > 0) {
    $sql .= ' AND s.rowid = '.((int) $socid);
}
if ($search_ref) {
    $sql .= natural_search('f.ref', $search_ref);
}
if ($search_type != '' && $search_type != '-1') {
    $sql .= " AND f.type IN (".$db->sanitize($db->escape($search_type)).")";
}
if ($search_montant_ttc != '') {
    $sql .= natural_search('pd.total_ttc', $search_montant_ttc, 1);
}
if ($search_montant_vat != '') {
    $sql .= natural_search('pd.total_tva', $search_montant_vat, 1);
}

if ($search_product_qty != '') {
    $sql .= natural_search('pd.qty', $search_product_qty, 1);
}

if ($search_categ_cus > 0) {
    $sql .= " AND cc.fk_categorie = ".((int) $search_categ_cus);
}
if ($search_categ_cus == -2) {
    $sql .= " AND cc.fk_categorie IS NULL";
}
if ($search_status != '-1' && $search_status != '') {
    if (is_numeric($search_status) && $search_status >= 0) {
        if ($search_status == '0') {
            $sql .= " AND f.fk_statut = 0"; // draft
        }
        if ($search_status == '1') {
            $sql .= " AND f.fk_statut = 1"; // unpayed
        }
        if ($search_status == '2') {
            $sql .= " AND f.fk_statut = 2"; // payed     Not that some corrupted data may contains f.fk_statut = 1 AND f.paye = 1 (it means payed too but should not happend. If yes, reopen and reclassify billed)
        }
        if ($search_status == '3') {
            $sql .= " AND f.fk_statut = 3"; // abandonned
        }
    } else {
        $sql .= " AND f.fk_statut IN (".$db->sanitize($db->escape($search_status)).")"; // When search_status is '1,2' for example
    }
}

if ($search_paymentmode > 0) {
    $sql .= " AND f.fk_mode_reglement = ".((int) $search_paymentmode);
}
if ($search_montant_ht > 0){
    $sql .= " AND pd.total_ht = ".((int) $search_montant_ht);
}
if ($search_tva_tx > 0) {
    $sql .= " AND pd.tva_tx = ".((int) $search_tva_tx);
}

if ($search_paymentterms > 0) {
    $sql .= " AND f.fk_cond_reglement = ".((int) $search_paymentterms);
}
if ($search_module_source) {
    $sql .= natural_search("f.module_source", $search_module_source);
}
if ($search_pos_source) {
    $sql .= natural_search("f.pos_source", $search_pos_source);
}
    $sql .= " AND f.pos_source >= 0";
if ($search_date_start) {
    $sql .= " AND f.datef >= '".$db->idate($search_date_start)."'";
}
if ($search_date_end) {
    $sql .= " AND f.datef <= '".$db->idate($search_date_end)."'";
}
if ($search_date_valid_start) {
    $sql .= " AND f.date_valid >= '".$db->idate($search_date_valid_start)."'";
}
if ($search_date_valid_end) {
    $sql .= " AND f.date_valid <= '".$db->idate($search_date_valid_end)."'";
}
if ($search_datelimit_start) {
    $sql .= " AND f.date_lim_reglement >= '".$db->idate($search_datelimit_start)."'";
}
if ($search_datelimit_end) {
    $sql .= " AND f.date_lim_reglement <= '".$db->idate($search_datelimit_end)."'";
}
if ($option == 'late') {
    $sql .= " AND f.date_lim_reglement < '".$db->idate(dol_now() - $conf->facture->client->warning_delay)."'";
}
// Add where from hooks
$parameters = array();
$reshook = $hookmanager->executeHooks('printFieldListWhere', $parameters); // Note that $action and $object may have been modified by hook
$sql .= $hookmanager->resPrint;

if (!$sall) {
    $sql .= ' GROUP BY f.rowid, f.ref, f.ref_client, f.fk_soc, f.type, f.note_private, f.note_public, f.increment, f.fk_mode_reglement, f.fk_cond_reglement, pd.total_ht, pd.total_tva, pd.qty, pd.total_ttc, pd.tva_tx ,';
    $sql .= ' f.localtax1, f.localtax2,';
    $sql .= ' f.datef, f.date_valid, f.date_lim_reglement, f.module_source, f.pos_source,';
    $sql .= ' f.paye, f.fk_statut, f.close_code,';
    $sql .= ' f.datec, f.tms, f.date_closing,';
    $sql .= ' f.retained_warranty, f.retained_warranty_date_limit, f.situation_final, f.situation_cycle_ref, f.situation_counter,';
    $sql .= ' f.multicurrency_total_tva, f.multicurrency_total_ttc,';
    $sql .= ' s.rowid, s.nom, s.name_alias, s.email, s.phone, s.fax, s.address, s.town, s.zip, s.fk_pays, s.client, s.fournisseur, s.code_client, s.code_fournisseur, s.code_compta, s.code_compta_fournisseur,';
    $sql .= ' typent.code,';
    $sql .= ' state.code_departement, state.nom,';
    $sql .= ' country.code, p.rowid , p.ref, pd.rowid';
    if ($search_categ_cus && $search_categ_cus != -1) {
        $sql .= ", cc.fk_categorie, cc.fk_soc";
    }
    // Add fields from extrafields
    if (!empty($extrafields->attributes[$object->table_element]['label'])) {
        foreach ($extrafields->attributes[$object->table_element]['label'] as $key => $val) {
            $sql .= ($extrafields->attributes[$object->table_element]['type'][$key] != 'separate' ? ", ef.".$key : '');
        }
    }
    // Add GroupBy from hooks
    $parameters = array('all' => !empty($all) ? $all : 0, 'fieldstosearchall' => $fieldstosearchall);
    $reshook = $hookmanager->executeHooks('printFieldListGroupBy', $parameters, $object); // Note that $action and $object may have been modified by hook
    $sql .= $hookmanager->resPrint;
} else {
    $sql .= natural_search(array_keys($fieldstosearchall), $sall);
}

// Add HAVING from hooks
$parameters = array();
$reshook = $hookmanager->executeHooks('printFieldListHaving', $parameters, $object); // Note that $action and $object may have been modified by hook
$sql .= empty($hookmanager->resPrint) ? "" : " HAVING 1=1 ".$hookmanager->resPrint;

$nbtotalofrecords = '';
if (empty($conf->global->MAIN_DISABLE_FULL_SCANLIST)) {
    $result = $db->query($sql);
    $nbtotalofrecords = $db->num_rows($result);
    if (($page * $limit) > $nbtotalofrecords) {	// if total resultset is smaller then paging size (filtering), goto and load page 0
        $page = 0;
        $offset = 0;
    }
}

$sql .= $db->plimit($limit + 1, $offset);
$resql = $db->query($sql);

if ($resql) {
    $num = $db->num_rows($resql);

    $arrayofselected = is_array($toselect) ? $toselect : array();

    if ($num == 1 && !empty($conf->global->MAIN_SEARCH_DIRECT_OPEN_IF_ONLY_ONE) && $sall) {
        $obj = $db->fetch_object($resql);
        $id = $obj->id;

        header("Location: ".DOL_URL_ROOT.'/compta/facture/card.php?facid='.$id);
        exit;
    }


    if ($socid) {
        $soc = new Societe($db);
        $soc->fetch($socid);
        if (empty($search_company)) {
            $search_company = $soc->name;
        }
    }

    $param = '&socid='.urlencode($socid);
    if (!empty($contextpage) && $contextpage != $_SERVER["PHP_SELF"]) {
        $param .= '&contextpage='.urlencode($contextpage);
    }
    if ($limit > 0 && $limit != $conf->liste_limit) {
        $param .= '&limit='.urlencode($limit);
    }
    if ($sall) {
        $param .= '&sall='.urlencode($sall);
    }
    if ($search_date_startday) {
        $param .= '&search_date_startday='.urlencode($search_date_startday);
    }
    if ($search_date_startmonth) {
        $param .= '&search_date_startmonth='.urlencode($search_date_startmonth);
    }
    if ($search_date_startyear) {
        $param .= '&search_date_startyear='.urlencode($search_date_startyear);
    }
    if ($search_date_endday) {
        $param .= '&search_date_endday='.urlencode($search_date_endday);
    }
    if ($search_date_endmonth) {
        $param .= '&search_date_endmonth='.urlencode($search_date_endmonth);
    }
    if ($search_date_endyear) {
        $param .= '&search_date_endyear='.urlencode($search_date_endyear);
    }
    if ($search_date_valid_startday) {
        $param .= '&search_date_valid_startday='.urlencode($search_date_valid_startday);
    }
    if ($search_date_valid_startmonth) {
        $param .= '&search_date_valid_startmonth='.urlencode($search_date_valid_startmonth);
    }
    if ($search_date_valid_startyear) {
        $param .= '&search_date_valid_startyear='.urlencode($search_date_valid_startyear);
    }
    if ($search_date_valid_endday) {
        $param .= '&search_date_valid_endday='.urlencode($search_date_valid_endday);
    }
    if ($search_date_valid_endmonth) {
        $param .= '&search_date_valid_endmonth='.urlencode($search_date_valid_endmonth);
    }
    if ($search_date_valid_endyear) {
        $param .= '&search_date_valid_endyear='.urlencode($search_date_valid_endyear);
    }
    if ($search_datelimit_startday) {
        $param .= '&search_datelimit_startday='.urlencode($search_datelimit_startday);
    }
    if ($search_datelimit_startmonth) {
        $param .= '&search_datelimit_startmonth='.urlencode($search_datelimit_startmonth);
    }
    if ($search_datelimit_startyear) {
        $param .= '&search_datelimit_startyear='.urlencode($search_datelimit_startyear);
    }
    if ($search_datelimit_endday) {
        $param .= '&search_datelimit_endday='.urlencode($search_datelimit_endday);
    }
    if ($search_datelimit_endmonth) {
        $param .= '&search_datelimit_endmonth='.urlencode($search_datelimit_endmonth);
    }
    if ($search_datelimit_endyear) {
        $param .= '&search_datelimit_endyear='.urlencode($search_datelimit_endyear);
    }
    if ($search_ref) {
        $param .= '&search_ref='.urlencode($search_ref);
    }
    if ($search_type != '') {
        $param .= '&search_type='.urlencode($search_type);
    }
    if ($search_company) {
        $param .= '&search_societe='.urlencode($search_company);
    }
    if ($search_product_category > 0) {
        $param .= '&search_product_category='.urlencode($search_product_category);
    }
    if ($search_montant_ht != '') {
        $param .= '&search_montant_ht='.urlencode($search_montant_ht);
    }
    if ($search_montant_vat != '') {
        $param .= '&search_montant_vat='.urlencode($search_montant_vat);
    }
    if ($search_montant_ttc != '') {
        $param .= '&search_montant_ttc='.urlencode($search_montant_ttc);
    }
    if ($search_tva_tx != '') {
        $param .= '&search_tva_tx='.urlencode($search_tva_tx);
    }
    if ($search_product_qty != '') {
        $param .= '&search_product_qty='.urlencode($search_product_qty);
    }
    if ($search_multicurrency_code != '') {
        $param .= '&search_multicurrency_code='.urlencode($search_multicurrency_code);
    }
    if ($search_multicurrency_tx != '') {
        $param .= '&search_multicurrency_tx='.urlencode($search_multicurrency_tx);
    }
    if ($search_multicurrency_montant_ht != '') {
        $param .= '&search_multicurrency_montant_ht='.urlencode($search_multicurrency_montant_ht);
    }
    if ($search_multicurrency_montant_vat != '') {
        $param .= '&search_multicurrency_montant_vat='.urlencode($search_multicurrency_montant_vat);
    }
    if ($search_multicurrency_montant_ttc != '') {
        $param .= '&search_multicurrency_montant_ttc='.urlencode($search_multicurrency_montant_ttc);
    }
    if ($search_status != '') {
        $param .= '&search_status='.urlencode($search_status);
    }
    if ($search_paymentmode > 0) {
        $param .= '&search_paymentmode='.urlencode($search_paymentmode);
    }
    if ($search_paymentterms > 0) {
        $param .= '&search_paymentterms='.urlencode($search_paymentterms);
    }
    if ($search_module_source) {
        $param .= '&search_module_source='.urlencode($search_module_source);
    }
    if ($search_pos_source) {
        $param .= '&search_pos_source='.urlencode($search_pos_source);
    }
    if ($show_files) {
        $param .= '&show_files='.urlencode($show_files);
    }
    if ($option) {
        $param .= "&search_option=".urlencode($option);
    }
    if ($optioncss != '') {
        $param .= '&optioncss='.urlencode($optioncss);
    }
    if ($search_categ_cus > 0) {
        $param .= '&search_categ_cus='.urlencode($search_categ_cus);
    }

    // Add $param from extra fields
    include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_list_search_param.tpl.php';
    // Add $param from hooks
    $parameters = array();
    $reshook = $hookmanager->executeHooks('printFieldListSearchParam', $parameters, $object); // Note that $action and $object may have been modified by hook
    $param .= $hookmanager->resPrint;

    $i = 0;
    print '<form method="POST" name="searchFormList" action="'.$_SERVER["PHP_SELF"].'">'."\n";

    if ($optioncss != '') {
        print '<input type="hidden" name="optioncss" value="'.$optioncss.'">';
    }
    print '<input type="hidden" name="token" value="'.newToken().'">';
    print '<input type="hidden" name="formfilteraction" id="formfilteraction" value="list">';
    print '<input type="hidden" name="sortfield" value="'.$sortfield.'">';
    print '<input type="hidden" name="sortorder" value="'.$sortorder.'">';
    print '<input type="hidden" name="search_status" value="'.$search_status.'">';
    print '<input type="hidden" name="contextpage" value="'.$contextpage.'">';

    print_barre_liste($langs->trans('ProductPOS').' '.($socid ? ' '.$soc->name : ''), $page, $_SERVER["PHP_SELF"], $param, $sortfield, $sortorder, "", $num, $nbtotalofrecords, 'bill', 0, "", '', $limit, 0, 0, 1);

    $objecttmp = new Facture($db);
    $trackid = 'inv'.$object->id;


    if ($sall) {
        foreach ($fieldstosearchall as $key => $val) {
            $fieldstosearchall[$key] = $langs->trans($val);
        }
        print '<div class="divsearchfieldfilter">'.$langs->trans("FilterOnInto", $sall).join(', ', $fieldstosearchall).'</div>';
    }

    // If the user can view prospects other than his'
    $moreforfilter = '';
    // Filter on product tags
    if (!empty($conf->categorie->enabled) && $user->rights->categorie->lire && ($user->rights->produit->lire || $user->rights->service->lire)) {
        include_once DOL_DOCUMENT_ROOT.'/categories/class/categorie.class.php';
        $moreforfilter .= '<div class="divsearchfield">';
        $tmptitle = $langs->trans('IncludingProductWithTag');
        $cate_arbo = $form->select_all_categories(Categorie::TYPE_PRODUCT, null, 'parent', null, null, 1);
        $moreforfilter .= img_picto($tmptitle, 'category', 'class="pictofixedwidth"').$form->selectarray('search_product_category', $cate_arbo, $search_product_category, $tmptitle, 0, 0, '', 0, 0, 0, 0, 'maxwidth250', 1);
        $moreforfilter .= '</div>';
    }
    $parameters = array();
    $reshook = $hookmanager->executeHooks('printFieldPreListTitle', $parameters); // Note that $action and $object may have been modified by hook
    if (empty($reshook)) {
        $moreforfilter .= $hookmanager->resPrint;
    } else {
        $moreforfilter = $hookmanager->resPrint;
    }

    if ($moreforfilter) {
        print '<div class="liste_titre liste_titre_bydiv centpercent">';
        print $moreforfilter;
        print '</div>';
    }

    $varpage = empty($contextpage) ? $_SERVER["PHP_SELF"] : $contextpage;
    $selectedfields = $form->multiSelectArrayWithCheckbox('selectedfields', $arrayfields, $varpage); // This also change content of $arrayfields


    print '<div class="div-table-responsive">';
    print '<table class="tagtable liste'.($moreforfilter ? " listwithfilterbefore" : "").'">'."\n";

    // Filters lines
    print '<tr class="liste_titre_filter">';
    if (!empty($conf->global->MAIN_VIEW_LINE_NUMBER_IN_LIST)) {
        print '<td class="liste_titre">';
        print '</td>';
    }
    // Ref
    if (!empty($arrayfields['f.ref']['checked'])) {
        print '<td class="liste_titre" align="left">';
        print '<input class="flat maxwidth50imp" type="text" name="search_ref" value="'.dol_escape_htmltag($search_ref).'">';
        print '</td>';
    }
    // Ref customer
    if (!empty($arrayfields['f.ref_client']['checked'])) {
        print '<td class="liste_titre">';
        print '<input class="flat maxwidth50imp" type="text" name="search_refcustomer" value="'.dol_escape_htmltag($search_refcustomer).'">';
        print '</td>';
    }

    // Date invoice
    if (!empty($arrayfields['f.datef']['checked'])) {
        print '<td class="liste_titre center">';
        print '<div class="nowrap">';
        print $form->selectDate($search_date_start ? $search_date_start : -1, 'search_date_start', 0, 0, 1, '', 1, 0, 0, '', '', '', '', 1, '', $langs->trans('From'));
        print '</div>';
        print '<div class="nowrap">';
        print $form->selectDate($search_date_end ? $search_date_end : -1, 'search_date_end', 0, 0, 1, '', 1, 0, 0, '', '', '', '', 1, '', $langs->trans('to'));
        print '</div>';
        print '</td>';
    }

    if (!empty($arrayfields['p.ref']['checked'])) {
        print '<td class="liste_titre">';
        $form->select_produits($search_refProduct, 'search_refProduct', '', 0, 1, 1, 10);
        print '</td>';
    }


    // Date valid
    if (!empty($arrayfields['f.date_valid']['checked'])) {
        print '<td class="liste_titre center">';
        print '<div class="nowrap">';
        print $form->selectDate($search_date_valid_start ? $search_date_valid_start : -1, 'search_date_valid_start', 0, 0, 1, '', 1, 0, 0, '', '', '', '', 1, '', $langs->trans('From'));
        print '</div>';
        print '<div class="nowrap">';
        print $form->selectDate($search_date_valid_end ? $search_date_valid_end : -1, 'search_date_valid_end', 0, 0, 1, '', 1, 0, 0, '', '', '', '', 1, '', $langs->trans('to'));
        print '</div>';
        print '</td>';
    }
    // Date due
    if (!empty($arrayfields['f.date_lim_reglement']['checked'])) {
        print '<td class="liste_titre center">';
        print '<div class="nowrap">';
        print $form->selectDate($search_datelimit_end ? $search_datelimit_end : -1, 'search_datelimit_end', 0, 0, 1, '', 1, 0, 0, '', '', '', '', 1, '', $langs->trans("Before"));
        print '<br><input type="checkbox" name="search_option" value="late"'.($option == 'late' ? ' checked' : '').'> '.$langs->trans("Alert");
        print '</div>';
        print '</td>';
    }

    // Thirdparty
    if (!empty($arrayfields['s.nom']['checked'])) {
        print '<td class="liste_titre"><input class="flat maxwidth75imp" type="text" name="search_company" value="'.$search_company.'"></td>';
    }
    // Payment mode
    if (!empty($arrayfields['f.fk_mode_reglement']['checked'])) {
        print '<td class="liste_titre">';
        $form->select_types_paiements($search_paymentmode, 'search_paymentmode', '', 0, 1, 1, 10);
        print '</td>';
    }
    // Payment terms
    if (!empty($arrayfields['f.fk_cond_reglement']['checked'])) {
        print '<td class="liste_titre">';
        $form->select_conditions_paiements($search_paymentterms, 'search_paymentterms', -1, 1, 1);
        print '</td>';
    }
    // Module source
    if (!empty($arrayfields['f.module_source']['checked'])) {
        print '<td class="liste_titre">';
        print '<input class="flat maxwidth75" type="text" name="search_module_source" value="'.dol_escape_htmltag($search_module_source).'">';
        print '</td>';
    }
    // POS Terminal
    if (!empty($arrayfields['f.pos_source']['checked'])) {
        print '<td class="liste_titre">';
        print '<input class="flat maxwidth50" type="text" name="search_pos_source" value="'.dol_escape_htmltag($search_pos_source).'">';
        print '</td>';
    }
    if (!empty($arrayfields['pd.total_ht']['checked'])) {
        // Amount
        print '<td class="liste_titre right">';
        print '<input class="flat" type="text" size="4" name="search_montant_ht" value="'.dol_escape_htmltag($search_montant_ht).'">';
        print '</td>';
    }
    if (!empty($arrayfields['pd.total_tva']['checked'])) {
        // Amount
        print '<td class="liste_titre right">';
        print '<input class="flat" type="text" size="4" name="search_montant_vat" value="'.dol_escape_htmltag($search_montant_vat).'">';
        print '</td>';
    }
    if (!empty($arrayfields['pd.qty']['checked'])) {
        // Amount
        print '<td class="liste_titre right">';
        print '<input class="flat" type="text" size="4" name="search_product_qty" value="'.dol_escape_htmltag($search_product_qty).'">';
        print '</td>';
    }
    if (!empty($arrayfields['pd.tva_tx']['checked'])) {
        // Amount
        print '<td class="liste_titre right">';
        print '<input class="flat" type="text" size="4" name="search_tva_tx" value="'.dol_escape_htmltag($search_tva_tx).'">';
        print '</td>';
    }
    if (!empty($arrayfields['pd.total_ttc']['checked'])) {
        // Amount
        print '<td class="liste_titre right">';
        print '<input class="flat" type="text" size="4" name="search_montant_ttc" value="'.dol_escape_htmltag($search_montant_ttc).'">';
        print '</td>';
    }
    if (!empty($arrayfields['sale_representative']['checked'])) {
        print '<td class="liste_titre"></td>';
    }
    if (!empty($arrayfields['f.retained_warranty']['checked'])) {
        print '<td class="liste_titre" align="right">';
        print '</td>';
    }
    if (!empty($arrayfields['dynamount_payed']['checked'])) {
        print '<td class="liste_titre right">';
        print '</td>';
    }
    if (!empty($arrayfields['rtp']['checked'])) {
        print '<td class="liste_titre right">';
        print '</td>';
    }
    if (!empty($arrayfields['f.multicurrency_code']['checked'])) {
        // Currency
        print '<td class="liste_titre">';
        print $form->selectMultiCurrency($search_multicurrency_code, 'search_multicurrency_code', 1);
        print '</td>';
    }
    if (!empty($arrayfields['f.multicurrency_tx']['checked'])) {
        // Currency rate
        print '<td class="liste_titre">';
        print '<input class="flat" type="text" size="4" name="search_multicurrency_tx" value="'.dol_escape_htmltag($search_multicurrency_tx).'">';
        print '</td>';
    }
    if (!empty($arrayfields['f.multicurrency_total_ht']['checked'])) {
        // Amount
        print '<td class="liste_titre right">';
        print '<input class="flat" type="text" size="4" name="search_multicurrency_montant_ht" value="'.dol_escape_htmltag($search_multicurrency_montant_ht).'">';
        print '</td>';
    }
    if (!empty($arrayfields['f.multicurrency_total_vat']['checked'])) {
        // Amount
        print '<td class="liste_titre right">';
        print '<input class="flat" type="text" size="4" name="search_multicurrency_montant_vat" value="'.dol_escape_htmltag($search_multicurrency_montant_vat).'">';
        print '</td>';
    }
    if (!empty($arrayfields['f.multicurrency_total_ttc']['checked'])) {
        // Amount
        print '<td class="liste_titre right">';
        print '<input class="flat" type="text" size="4" name="search_multicurrency_montant_ttc" value="'.dol_escape_htmltag($search_multicurrency_montant_ttc).'">';
        print '</td>';
    }
    if (!empty($arrayfields['multicurrency_dynamount_payed']['checked'])) {
        print '<td class="liste_titre">';
        print '</td>';
    }
    if (!empty($arrayfields['multicurrency_rtp']['checked'])) {
        print '<td class="liste_titre right">';
        print '</td>';
    }
    if (!empty($arrayfields['total_pa']['checked'])) {
        print '<td class="liste_titre right">';
        print '</td>';
    }
    if (!empty($arrayfields['total_margin']['checked'])) {
        print '<td class="liste_titre right">';
        print '</td>';
    }
    if (!empty($arrayfields['total_margin_rate']['checked'])) {
        print '<td class="liste_titre right">';
        print '</td>';
    }
    if (!empty($arrayfields['total_mark_rate']['checked'])) {
        print '<td class="liste_titre right">';
        print '</td>';
    }

    // Extra fields
    include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_list_search_input.tpl.php';

    // Fields from hook
    $parameters = array('arrayfields'=>$arrayfields);
    $reshook = $hookmanager->executeHooks('printFieldListOption', $parameters); // Note that $action and $object may have been modified by hook
    print $hookmanager->resPrint;
    // Date creation
    if (!empty($arrayfields['f.datec']['checked'])) {
        print '<td class="liste_titre">';
        print '</td>';
    }
    // Date modification
    if (!empty($arrayfields['f.tms']['checked'])) {
        print '<td class="liste_titre">';
        print '</td>';
    }
    // Date closing
    if (!empty($arrayfields['f.date_closing']['checked'])) {
        print '<td class="liste_titre">';
        print '</td>';
    }
    if (!empty($arrayfields['f.note_public']['checked'])) {
        // Note public
        print '<td class="liste_titre">';
        print '</td>';
    }
    if (!empty($arrayfields['f.note_private']['checked'])) {
        // Note private
        print '<td class="liste_titre">';
        print '</td>';
    }
    // Status
    if (!empty($arrayfields['f.fk_statut']['checked'])) {
        print '<td class="liste_titre maxwidthonsmartphone right">';
        $liststatus = array('0'=>$langs->trans("BillShortStatusDraft"), '1'=>$langs->trans("BillShortStatusNotPaid"), '0,1'=>$langs->trans("BillShortStatusDraft").'+'.$langs->trans("BillShortStatusNotPaid"), '2'=>$langs->trans("BillShortStatusPaid"), '1,2'=>$langs->trans("BillShortStatusNotPaid").'+'.$langs->trans("BillShortStatusPaid"), '3'=>$langs->trans("BillShortStatusCanceled"));
        print $form->selectarray('search_status', $liststatus, $search_status, 1, 0, 0, '', 0, 0, 0, '', '', 1);
        print '</td>';
    }
    // Action column
    print '<td class="liste_titre" align="middle">';
    $searchpicto = $form->showFilterButtons();
    print $searchpicto;
    print '</td>';
    print "</tr>\n";

    print '<tr class="liste_titre">';
    if (!empty($conf->global->MAIN_VIEW_LINE_NUMBER_IN_LIST)) {
        print_liste_field_titre('#', $_SERVER['PHP_SELF'], '', '', $param, '', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.ref']['checked'])) {
        print_liste_field_titre($arrayfields['f.ref']['label'], $_SERVER['PHP_SELF'], 'f.ref', '', $param, '', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.ref_client']['checked'])) {
        print_liste_field_titre($arrayfields['f.ref_client']['label'], $_SERVER["PHP_SELF"], 'f.ref_client', '', $param, '', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.datef']['checked'])) {
        print_liste_field_titre($arrayfields['f.datef']['label'], $_SERVER['PHP_SELF'], 'f.datef', '', $param, 'align="center"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.date_valid']['checked'])) {
        print_liste_field_titre($arrayfields['f.date_valid']['label'], $_SERVER['PHP_SELF'], 'f.date_valid', '', $param, 'align="center"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['p.ref']['checked'])) {
        print_liste_field_titre($arrayfields['p.ref']['label'], $_SERVER["PHP_SELF"], "p.ref", "", $param, "", $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.fk_mode_reglement']['checked'])) {
        print_liste_field_titre($arrayfields['f.fk_mode_reglement']['label'], $_SERVER["PHP_SELF"], "f.fk_mode_reglement", "", $param, "", $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.fk_cond_reglement']['checked'])) {
        print_liste_field_titre($arrayfields['f.fk_cond_reglement']['label'], $_SERVER["PHP_SELF"], "f.fk_cond_reglement", "", $param, "", $sortfield, $sortorder);
    }

    if (!empty($arrayfields['f.module_source']['checked'])) {
        print_liste_field_titre($arrayfields['f.module_source']['label'], $_SERVER["PHP_SELF"], "f.module_source", "", $param, "", $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.pos_source']['checked'])) {
        print_liste_field_titre($arrayfields['f.pos_source']['label'], $_SERVER["PHP_SELF"], "f.pos_source", "", $param, "", $sortfield, $sortorder);
    }
    if (!empty($arrayfields['pd.total_ht']['checked'])) {
        print_liste_field_titre($arrayfields['pd.total_ht']['label'], $_SERVER['PHP_SELF'], 'pd.total_ht', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['pd.total_tva']['checked'])) {
        print_liste_field_titre($arrayfields['pd.total_tva']['label'], $_SERVER['PHP_SELF'], 'pd.total_tva', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['pd.qty']['checked'])) {
        print_liste_field_titre($arrayfields['pd.qty']['label'], $_SERVER['PHP_SELF'], 'pd.qty', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['pd.tva_tx']['checked'])) {
        print_liste_field_titre($arrayfields['pd.tva_tx']['label'], $_SERVER['PHP_SELF'], 'pd.tva_tx', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.total_localtax1']['checked'])) {
        print_liste_field_titre($arrayfields['f.total_localtax1']['label'], $_SERVER['PHP_SELF'], 'f.localtax1', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.total_localtax2']['checked'])) {
        print_liste_field_titre($arrayfields['f.total_localtax2']['label'], $_SERVER['PHP_SELF'], 'f.localtax2', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['pd.total_ttc']['checked'])) {
        print_liste_field_titre($arrayfields['pd.total_ttc']['label'], $_SERVER['PHP_SELF'], 'pd.total_ttc', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['u.login']['checked'])) {
        print_liste_field_titre($arrayfields['u.login']['label'], $_SERVER["PHP_SELF"], 'u.login', '', $param, 'align="center"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['sale_representative']['checked'])) {
        print_liste_field_titre($arrayfields['sale_representative']['label'], $_SERVER["PHP_SELF"], "", "", "$param", '', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.retained_warranty']['checked'])) {
        print_liste_field_titre($arrayfields['f.retained_warranty']['label'], $_SERVER['PHP_SELF'], '', '', $param, 'align="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['dynamount_payed']['checked'])) {
        print_liste_field_titre($arrayfields['dynamount_payed']['label'], $_SERVER['PHP_SELF'], '', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['rtp']['checked'])) {
        print_liste_field_titre($arrayfields['rtp']['label'], $_SERVER['PHP_SELF'], '', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.multicurrency_code']['checked'])) {
        print_liste_field_titre($arrayfields['f.multicurrency_code']['label'], $_SERVER['PHP_SELF'], 'f.multicurrency_code', '', $param, '', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.multicurrency_tx']['checked'])) {
        print_liste_field_titre($arrayfields['f.multicurrency_tx']['label'], $_SERVER['PHP_SELF'], 'f.multicurrency_tx', '', $param, '', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.multicurrency_total_ht']['checked'])) {
        print_liste_field_titre($arrayfields['f.multicurrency_total_ht']['label'], $_SERVER['PHP_SELF'], 'f.multicurrency_total_ht', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.multicurrency_total_vat']['checked'])) {
        print_liste_field_titre($arrayfields['f.multicurrency_total_vat']['label'], $_SERVER['PHP_SELF'], 'f.multicurrency_total_tva', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.multicurrency_total_ttc']['checked'])) {
        print_liste_field_titre($arrayfields['f.multicurrency_total_ttc']['label'], $_SERVER['PHP_SELF'], 'f.multicurrency_total_ttc', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['multicurrency_dynamount_payed']['checked'])) {
        print_liste_field_titre($arrayfields['multicurrency_dynamount_payed']['label'], $_SERVER['PHP_SELF'], '', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['multicurrency_rtp']['checked'])) {
        print_liste_field_titre($arrayfields['multicurrency_rtp']['label'], $_SERVER['PHP_SELF'], '', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['total_pa']['checked'])) {
        print_liste_field_titre($arrayfields['total_pa']['label'], $_SERVER['PHP_SELF'], '', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['total_margin']['checked'])) {
        print_liste_field_titre($arrayfields['total_margin']['label'], $_SERVER['PHP_SELF'], '', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['total_margin_rate']['checked'])) {
        print_liste_field_titre($arrayfields['total_margin_rate']['label'], $_SERVER['PHP_SELF'], '', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['total_mark_rate']['checked'])) {
        print_liste_field_titre($arrayfields['total_mark_rate']['label'], $_SERVER['PHP_SELF'], '', '', $param, 'class="right"', $sortfield, $sortorder);
    }
    // Extra fields
    include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_list_search_title.tpl.php';
    // Hook fields
    $parameters = array('arrayfields'=>$arrayfields, 'param'=>$param, 'sortfield'=>$sortfield, 'sortorder'=>$sortorder);
    $reshook = $hookmanager->executeHooks('printFieldListTitle', $parameters); // Note that $action and $object may have been modified by hook
    print $hookmanager->resPrint;
    if (!empty($arrayfields['f.datec']['checked'])) {
        print_liste_field_titre($arrayfields['f.datec']['label'], $_SERVER["PHP_SELF"], "f.datec", "", $param, 'align="center" class="nowrap"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.tms']['checked'])) {
        print_liste_field_titre($arrayfields['f.tms']['label'], $_SERVER["PHP_SELF"], "f.tms", "", $param, 'align="center" class="nowrap"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.date_closing']['checked'])) {
        print_liste_field_titre($arrayfields['f.date_closing']['label'], $_SERVER["PHP_SELF"], "f.date_closing", "", $param, 'align="center" class="nowrap"', $sortfield, $sortorder);
    }
    if (!empty($arrayfields['f.note_public']['checked'])) {
        print_liste_field_titre($arrayfields['f.note_public']['label'], $_SERVER["PHP_SELF"], "f.note_public", "", $param, '', $sortfield, $sortorder, 'center nowrap ');
    }
    if (!empty($arrayfields['f.note_private']['checked'])) {
        print_liste_field_titre($arrayfields['f.note_private']['label'], $_SERVER["PHP_SELF"], "f.note_private", "", $param, '', $sortfield, $sortorder, 'center nowrap ');
    }
    if (!empty($arrayfields['f.fk_statut']['checked'])) {
        print_liste_field_titre($arrayfields['f.fk_statut']['label'], $_SERVER["PHP_SELF"], "f.fk_statut,f.paye,f.type,dynamount_payed", "", $param, 'class="right"', $sortfield, $sortorder);
    }
    print_liste_field_titre($selectedfields, $_SERVER["PHP_SELF"], "", '', '', 'align="center"', $sortfield, $sortorder, 'maxwidthsearch ');
    print "</tr>\n";

    $discount = new DiscountAbsolute($db);
    $userstatic = new User($db);

    if ($num > 0) {
        $i = 0;
        $totalarray = array();
        $totalarray['nbfield'] = 0;
        $totalarray['val'] = array();
        $totalarray['val']['pd.total_ht'] = 0;
        $totalarray['val']['pd.total_ttc'] = 0;
        while ($i < min($num, $limit)) {
            $obj = $db->fetch_object($resql);

            $datelimit = $db->jdate($obj->datelimite);

            $facturestatic->id = $obj->id;
            $facturestatic->ref = $obj->ref;
            $facturestatic->ref_client = $obj->ref_client;
            $facturestatic->type = $obj->type;
            $facturestatic->total_ht = $obj->total_ht;
            $facturestatic->total_tva = $obj->total_tva;
            $facturestatic->total_ttc = $obj->total_ttc;
            $facturestatic->multicurrency_code = $obj->multicurrency_code;
            $facturestatic->multicurrency_tx = $obj->multicurrency_tx;
            $facturestatic->multicurrency_total_ht = $obj->multicurrency_total_ht;
            $facturestatic->multicurrency_total_tva = $obj->multicurrency_total_vat;
            $facturestatic->multicurrency_total_ttc = $obj->multicurrency_total_ttc;
            $facturestatic->statut = $obj->fk_statut;
            $facturestatic->close_code = $obj->close_code;
            $facturestatic->total_ttc = $obj->total_ttc;
            $facturestatic->paye = $obj->paye;
            $facturestatic->fk_soc = $obj->fk_soc;

            $facturestatic->date = $db->jdate($obj->datef);
            $facturestatic->date_valid = $db->jdate($obj->date_valid);
            $facturestatic->date_lim_reglement = $db->jdate($obj->datelimite);

            $facturestatic->note_public = $obj->note_public;
            $facturestatic->note_private = $obj->note_private;
            if (!empty($conf->global->INVOICE_USE_SITUATION) && !empty($conf->global->INVOICE_USE_RETAINED_WARRANTY)) {
                $facturestatic->retained_warranty = $obj->retained_warranty;
                $facturestatic->retained_warranty_date_limit = $obj->retained_warranty_date_limit;
                $facturestatic->situation_final = $obj->retained_warranty_date_limit;
                $facturestatic->situation_final = $obj->retained_warranty_date_limit;
                $facturestatic->situation_cycle_ref = $obj->situation_cycle_ref;
                $facturestatic->situation_counter = $obj->situation_counter;
            }
            $companystatic->id = $obj->socid;
            $companystatic->name = $obj->name;
            $companystatic->name_alias = $obj->alias;
            $companystatic->client = $obj->client;
            $companystatic->fournisseur = $obj->fournisseur;
            $companystatic->code_client = $obj->code_client;
            $companystatic->code_compta_client = $obj->code_compta_client;
            $companystatic->code_fournisseur = $obj->code_fournisseur;
            $companystatic->code_compta_fournisseur = $obj->code_compta_fournisseur;
            $companystatic->email = $obj->email;
            $companystatic->phone = $obj->phone;
            $companystatic->fax = $obj->fax;
            $companystatic->address = $obj->address;
            $companystatic->zip = $obj->zip;
            $companystatic->town = $obj->town;
            $companystatic->country_code = $obj->country_code;


            $paiement = $facturestatic->getSommePaiement();
            $totalcreditnotes = $facturestatic->getSumCreditNotesUsed();
            $totaldeposits = $facturestatic->getSumDepositsUsed();
            $totalpay = $paiement + $totalcreditnotes + $totaldeposits;
            $remaintopay = price2num($facturestatic->total_ttc - $totalpay);
            $multicurrency_paiement = $facturestatic->getSommePaiement(1);
            $multicurrency_totalcreditnotes = $facturestatic->getSumCreditNotesUsed(1);
            $multicurrency_totaldeposits = $facturestatic->getSumDepositsUsed(1);
            $multicurrency_totalpay = $multicurrency_paiement + $multicurrency_totalcreditnotes + $multicurrency_totaldeposits;
            $multicurrency_remaintopay = price2num($facturestatic->multicurrency_total_ttc - $multicurrency_totalpay);
            $facturestatic->alreadypaid = $paiement;


            print '<tr class="oddeven"';
            if ($contextpage == 'poslist') {
                print ' onclick="parent.$(\'#poslines\').load(\'invoice.php?action=history&placeid='.$obj->id.'\', function() {parent.$.colorbox.close();';
                if (strpos($obj->ref, 'PROV') !== false) {
                    //If is a draft invoice, load var to be able to add products
                    $place = str_replace(")", "", str_replace("(PROV-POS".$_SESSION["takeposterminal"]."-", "", $obj->ref));
                    print 'parent.place=\''.$place.'\'';
                }
                print '});"';
            }
            print '>';

            // No
            if (!empty($conf->global->MAIN_VIEW_LINE_NUMBER_IN_LIST)) {
                print '<td>'.(($offset * $limit) + $i).'</td>';
            }

            // Ref
            if (!empty($arrayfields['f.ref']['checked'])) {
                print '<td class="nowraponall">';

                print '<table class="nobordernopadding"><tr class="nocellnopadd">';

                print '<td class="nobordernopadding nowraponall">';
                if ($contextpage == 'poslist') {
                    print dol_escape_htmltag($obj->ref);
                } else {
                    print $facturestatic->getNomUrl(1, '', 200, 0, '', 0, 1);
                }

                $filename = dol_sanitizeFileName($obj->ref);
                $filedir = $conf->facture->dir_output.'/'.dol_sanitizeFileName($obj->ref);
                $urlsource = $_SERVER['PHP_SELF'].'?id='.$obj->id;
                print $formfile->getDocumentsLink($facturestatic->element, $filename, $filedir);
                print '</td>';
                print '</tr>';
                print '</table>';

                print "</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }



            // Customer ref
            if (!empty($arrayfields['f.ref_client']['checked'])) {
                print '<td class="nowrap tdoverflowmax200">';
                print dol_escape_htmltag($obj->ref_client);
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }

            // Date
            if (!empty($arrayfields['f.datef']['checked'])) {
                print '<td align="center" class="nowraponall">';
                print dol_print_date($db->jdate($obj->datef), 'day');
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }

            // Date
            if (!empty($arrayfields['f.date_valid']['checked'])) {
                print '<td align="center" class="nowraponall">';
                print dol_print_date($db->jdate($obj->date_valid), 'day');
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }

            // Date limit
            if (!empty($arrayfields['f.date_lim_reglement']['checked'])) {
                print '<td align="center" class="nowraponall">'.dol_print_date($datelimit, 'day');
                if ($facturestatic->hasDelay()) {
                    print img_warning($langs->trans('Alert').' - '.$langs->trans('Late'));
                }
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }
            if (!empty($arrayfields['p.ref']['checked'])) {
                print '<td class="nowraponall">';

                print '<table class="nobordernopadding"><tr class="nocellnopadd">';

                print '<td class="nobordernopadding nowraponall">';
                $productstatic = New Product($db);
                $categorie = new Categorie($db);
                $productstatic->fetch($obj->product_id);
                print $productstatic->getNomUrl(1, '', 200, 0, '', 0, 1);
                print " - ";
                print $productstatic->label;
                if (!empty($categorie->containing($obj->product_id, Categorie::TYPE_PRODUCT)[0]->label)){
                    print " ( ";
                    print $categorie->containing($obj->product_id, Categorie::TYPE_PRODUCT)[0]->label;
                    print " )";
                }
                print '</td>';
                print '</tr>';
                print '</table>';

                print "</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }


            // Third party
            if (!empty($arrayfields['s.nom']['checked'])) {
                print '<td class="tdoverflowmax200">';
                if ($contextpage == 'poslist') {
                    print dol_escape_htmltag($companystatic->name);
                } else {
                    print $companystatic->getNomUrl(1, 'customer', 0, 0, -1, empty($arrayfields['s.name_alias']['checked']) ? 0 : 1);
                }
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }
            // Alias
            if (!empty($arrayfields['s.name_alias']['checked'])) {
                print '<td class="tdoverflowmax150" title="'.dol_escape_htmltag($companystatic->name_alias).'">';
                print dol_escape_htmltag($companystatic->name_alias);
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }
            // Town
            if (!empty($arrayfields['s.town']['checked'])) {
                print '<td class="tdoverflowmax100" title="'.dol_escape_htmltag($obj->town).'">';
                print dol_escape_htmltag($obj->town);
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }
            // Zip
            if (!empty($arrayfields['s.zip']['checked'])) {
                print '<td class="nowraponall">';
                print dol_escape_htmltag($obj->zip);
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }
            // State
            if (!empty($arrayfields['state.nom']['checked'])) {
                print "<td>".dol_escape_htmltag($obj->state_name)."</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }

            // Staff
            if (!empty($arrayfields['staff.code']['checked'])) {
                print '<td class="center">';
                if (!is_array($conf->cache['staff']) || count($conf->cache['staff']) == 0) {
                    $conf->cache['staff'] = $formcompany->effectif_array(1);
                }
                print $conf->cache['staff'][$obj->staff_code];
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }

            // Payment mode
            if (!empty($arrayfields['f.fk_mode_reglement']['checked'])) {
                print '<td class="tdoverflowmax100">';
                $form->form_modes_reglement($_SERVER['PHP_SELF'], $obj->fk_mode_reglement, 'none', '', -1);
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }

            // Payment terms
            if (!empty($arrayfields['f.fk_cond_reglement']['checked'])) {
                print '<td>';
                $form->form_conditions_reglement($_SERVER['PHP_SELF'], $obj->fk_cond_reglement, 'none');
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }

            // Module Source
            if (!empty($arrayfields['f.module_source']['checked'])) {
                print '<td>';
                print dol_escape_htmltag($obj->module_source);
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }

            // POS Terminal
            if (!empty($arrayfields['f.pos_source']['checked'])) {
                print '<td>';
                print dol_escape_htmltag($obj->pos_source);
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }

            // Amount HT
            if (!empty($arrayfields['pd.total_ht']['checked'])) {
                print '<td class="right nowraponall">'.price($obj->total_ht)."</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                if (!$i) {
                    $totalarray['pos'][$totalarray['nbfield']] = 'pd.total_ht';
                }
                $totalarray['val']['pd.total_ht'] += $obj->total_ht;
            }
            // Amount VAT
            if (!empty($arrayfields['pd.total_tva']['checked'])) {
                print '<td class="right nowraponall amount">'.price($obj->total_tva)."</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                if (!$i) {
                    $totalarray['pos'][$totalarray['nbfield']] = 'pd.total_tva';
                }
                $totalarray['val']['pd.total_tva'] += $obj->total_tva;
            }
            if (!empty($arrayfields['pd.qty']['checked'])) {
                print '<td class="right nowraponall amount">'.$obj->qty."</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                if (!$i) {
                    $totalarray['pos'][$totalarray['nbfield']] = 'pd.qty';
                }
                $totalarray['val']['pd.qty'] += $obj->qty;
            }
            // Amount VAT
            if (!empty($arrayfields['pd.tva_tx']['checked'])) {
                print '<td class="right nowraponall amount">'.round($obj->tva_tx,1)." %</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }

            }
            // Amount TTC
            if (!empty($arrayfields['pd.total_ttc']['checked'])) {
                print '<td class="right nowraponall amount">'.price($obj->total_ttc)."</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                if (!$i) {
                    $totalarray['pos'][$totalarray['nbfield']] = 'pd.total_ttc';
                }
                $totalarray['val']['pd.total_ttc'] += $obj->total_ttc;
            }




            // Pending amount
            if (!empty($arrayfields['rtp']['checked'])) {
                print '<td class="right nowraponall amount">';
                print (!empty($remaintopay) ? price($remaintopay, 0, $langs) : '&nbsp;');
                print '</td>'; // TODO Use a denormalized field
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                if (!$i) {
                    $totalarray['pos'][$totalarray['nbfield']] = 'rtp';
                }
                $totalarray['val']['rtp'] += $remaintopay;
            }


            // Currency
            if (!empty($arrayfields['f.multicurrency_code']['checked'])) {
                print '<td class="nowraponall">'.dol_escape_htmltag($obj->multicurrency_code).' - '.$langs->trans('Currency'.$obj->multicurrency_code)."</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }

            // Currency rate
            if (!empty($arrayfields['f.multicurrency_tx']['checked'])) {
                print '<td class="nowraponall">';
                $form->form_multicurrency_rate($_SERVER['PHP_SELF'].'?id='.$obj->rowid, $obj->multicurrency_tx, 'none', $obj->multicurrency_code);
                print "</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }
            // Amount HT
            if (!empty($arrayfields['f.multicurrency_total_ht']['checked'])) {
                print '<td class="right nowraponall amount">'.price($obj->multicurrency_total_ht)."</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }
            // Amount VAT
            if (!empty($arrayfields['f.multicurrency_total_vat']['checked'])) {
                print '<td class="right nowraponall amount">'.price($obj->multicurrency_total_vat)."</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }
            // Amount TTC
            if (!empty($arrayfields['f.multicurrency_total_ttc']['checked'])) {
                print '<td class="right nowraponall amount">'.price($obj->multicurrency_total_ttc)."</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }
            if (!empty($arrayfields['multicurrency_dynamount_payed']['checked'])) {
                print '<td class="right nowraponall amount">'.(!empty($multicurrency_totalpay) ?price($multicurrency_totalpay, 0, $langs) : '&nbsp;').'</td>'; // TODO Use a denormalized field
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }

            // Pending amount
            if (!empty($arrayfields['multicurrency_rtp']['checked'])) {
                print '<td class="right nowraponall">';
                print (!empty($multicurrency_remaintopay) ? price($multicurrency_remaintopay, 0, $langs) : '&nbsp;');
                print '</td>'; // TODO Use a denormalized field
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }

            // Total buying or cost price
            if (!empty($arrayfields['total_pa']['checked'])) {
                print '<td class="right nowrap">'.price($marginInfo['pa_total']).'</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }
            // Total margin
            if (!empty($arrayfields['total_margin']['checked'])) {
                print '<td class="right nowrap">'.price($marginInfo['total_margin']).'</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                if (!$i) {
                    $totalarray['pos'][$totalarray['nbfield']] = 'total_margin';
                }
                $totalarray['val']['total_margin'] += $marginInfo['total_margin'];
            }
            // Total margin rate
            if (!empty($arrayfields['total_margin_rate']['checked'])) {
                print '<td class="right nowrap">'.(($marginInfo['total_margin_rate'] == '') ? '' : price($marginInfo['total_margin_rate'], null, null, null, null, 2).'%').'</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }
            // total mark rate
            if (!empty($arrayfields['total_mark_rate']['checked'])) {
                print '<td class="right nowrap">'.(($marginInfo['total_mark_rate'] == '') ? '' : price($marginInfo['total_mark_rate'], null, null, null, null, 2).'%').'</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }
            // Extra fields
            include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_list_print_fields.tpl.php';
            // Fields from hook
            $parameters = array('arrayfields'=>$arrayfields, 'obj'=>$obj, 'i'=>$i, 'totalarray'=>&$totalarray);
            $reshook = $hookmanager->executeHooks('printFieldListValue', $parameters); // Note that $action and $object may have been modified by hook
            print $hookmanager->resPrint;
            // Date creation
            if (!empty($arrayfields['f.datec']['checked'])) {
                print '<td class="nowrap center">';
                print dol_print_date($db->jdate($obj->date_creation), 'dayhour', 'tzuser');
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }
            // Status
            if (!empty($arrayfields['f.fk_statut']['checked'])) {
                print '<td class="nowrap right">';
                print $facturestatic->LibStatut($obj->paye, $obj->fk_statut, 5, $paiement, $obj->type);
                print "</td>";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
            }

            if (!$i) {
                $totalarray['nbfield']++;
            }

            print "</tr>\n";

            $i++;
        }

        // Show total line
        include DOL_DOCUMENT_ROOT.'/core/tpl/list_print_total.tpl.php';
    }

    $db->free($resql);

    $parameters = array('arrayfields'=>$arrayfields, 'sql'=>$sql);
    $reshook = $hookmanager->executeHooks('printFieldListFooter', $parameters); // Note that $action and $object may have been modified by hook
    print $hookmanager->resPrint;

    print "</table>\n";
    print '</div>';

    print "</form>\n";

    // Show the file area only when this page is not opend from the Extended POS
} else {
    dol_print_error($db);
}

// End of page
llxFooter();
$db->close();
