<?php
/* Copyright (C) 2001-2002  Rodolphe Quiedeville <rodolphe@quiedeville.org>
 * Copyright (C) 2004-2020  Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2005-2010  Regis Houssin        <regis.houssin@capnetworks.com>
 * Copyright (C) 2012       Vinícius Nogueira    <viniciusvgn@gmail.com>
 * Copyright (C) 2014       Florian Henry        <florian.henry@open-cooncept.pro>
 * Copyright (C) 2015       Jean-François Ferry  <jfefe@aternatik.fr>
 * Copyright (C) 2016       Juanjo Menent        <jmenent@2byte.es>
 * Copyright (C) 2017       Alexandre Spangaro   <aspangaro@open-dsi.fr>
 * Copyright (C) 2018       Andreu Bisquerra	 <jove@bisquerra.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

/**
 *    \file       htdocs/compta/cashcontrol/report.php
 *    \ingroup    cashdesk|takepos
 *    \brief      List of sales from POS
 */
// Load Dolibarr environment
$res = 0;
// Try main.inc.php into web root known defined into CONTEXT_DOCUMENT_ROOT (not always defined)
if (!$res && !empty($_SERVER["CONTEXT_DOCUMENT_ROOT"])) {
    $res = @include $_SERVER["CONTEXT_DOCUMENT_ROOT"] . "/main.inc.php";
}
// Try main.inc.php into web root detected using web root calculated from SCRIPT_FILENAME
$tmp = empty($_SERVER['SCRIPT_FILENAME']) ? '' : $_SERVER['SCRIPT_FILENAME'];
$tmp2 = realpath(__FILE__);
$i = strlen($tmp) - 1;
$j = strlen($tmp2) - 1;
while ($i > 0 && $j > 0 && isset($tmp[$i]) && isset($tmp2[$j]) && $tmp[$i] == $tmp2[$j]) {
    $i--;
    $j--;
}
if (!$res && $i > 0 && file_exists(substr($tmp, 0, ($i + 1)) . "/main.inc.php")) {
    $res = @include substr($tmp, 0, ($i + 1)) . "/main.inc.php";
}
if (!$res && $i > 0 && file_exists(dirname(substr($tmp, 0, ($i + 1))) . "/main.inc.php")) {
    $res = @include dirname(substr($tmp, 0, ($i + 1))) . "/main.inc.php";
}
// Try main.inc.php using relative path
if (!$res && file_exists("../main.inc.php")) {
    $res = @include "../main.inc.php";
}
if (!$res && file_exists("../../main.inc.php")) {
    $res = @include "../../main.inc.php";
}
if (!$res && file_exists("../../../main.inc.php")) {
    $res = @include "../../../main.inc.php";
}
if (!$res) {
    die("Include of main fails");
}

if (!defined('NOREQUIREMENU')) {
    define('NOREQUIREMENU', '1'); // If there is no need to load and show top and left menu
}
if (!defined('NOBROWSERNOTIF')) {
    define('NOBROWSERNOTIF', '1'); // Disable browser notification
}

$_GET['optioncss'] = "print";

require_once DOL_DOCUMENT_ROOT . '/compta/cashcontrol/class/cashcontrol.class.php';
require_once DOL_DOCUMENT_ROOT . '/compta/bank/class/account.class.php';
require_once DOL_DOCUMENT_ROOT . '/compta/facture/class/facture.class.php';
require_once DOL_DOCUMENT_ROOT . '/compta/cashcontrol/class/cashcontrol.class.php';
require_once DOL_DOCUMENT_ROOT . '/core/lib/date.lib.php';
require_once DOL_DOCUMENT_ROOT . '/product/class/product.class.php';

$langs->load("advancedpos@advancedpos");

$langs->loadLangs(array("bills", "banks", "products"));

$id = GETPOST('id', 'int');

$object = new CashControl($db);
$object->fetch($id);

//$limit = GETPOST('limit')?GETPOST('limit', 'int'):$conf->liste_limit;
$sortorder = 'ASC';
$sortfield = 'b.datev,b.dateo,b.rowid';

$arrayfields = array(
    'p.categ' => array('label' => $langs->trans("Rubriques")),
    'c.nbr' => array('label' => $langs->trans("categNbr")),
    'c.HT' => array('label' => $langs->trans("HT")),
    'c.tva' => array('label' => $langs->trans("TVA")),
    'c.ttc' => array('label' => $langs->trans("SellingPrice_TTC")),
);

$syear = $object->year_close;
$smonth = $object->month_close;
$sday = $object->day_close;

$posmodule = $object->posmodule;
$terminalid = $object->posnumber;

// Security check
if ($user->socid > 0) {    // Protection if external user
    //$socid = $user->socid;
    accessforbidden();
}
if (empty($user->rights->cashdesk->run) && empty($user->rights->takepos->run)) {
    accessforbidden();
}


/*
 * View
 */

$title = $langs->trans("CashControl");
$param = '';

llxHeader('', $title, '', '', 0, 0, array(), array(), $param);

/*$sql = "SELECT b.rowid, b.dateo as do, b.datev as dv, b.amount, b.label, b.rappro as conciliated, b.num_releve, b.num_chq,";
$sql.= " b.fk_account, b.fk_type,";
$sql.= " ba.rowid as bankid, ba.ref as bankref,";
$sql.= " bu.url_id,";
$sql.= " f.module_source, f.ref as ref";
$sql.= " FROM ";
//if ($bid) $sql.= MAIN_DB_PREFIX."bank_class as l,";
$sql.= " ".MAIN_DB_PREFIX."bank_account as ba,";
$sql.= " ".MAIN_DB_PREFIX."bank as b";
$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."bank_url as bu ON bu.fk_bank = b.rowid AND type = 'payment'";
$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."facture as f ON bu.url_id = f.rowid";
$sql.= " WHERE b.fk_account = ba.rowid";
// Define filter on invoice
$sql.= " AND f.module_source = '".$db->escape($object->posmodule)."'";
$sql.= " AND f.pos_source = '".$db->escape($object->posnumber)."'";
$sql.= " AND f.entity IN (".getEntity('facture').")";
// Define filter on data
if ($syear && ! $smonth)              $sql.= " AND dateo BETWEEN '".$db->idate(dol_get_first_day($syear, 1))."' AND '".$db->idate(dol_get_last_day($syear, 12))."'";
elseif ($syear && $smonth && ! $sday) $sql.= " AND dateo BETWEEN '".$db->idate(dol_get_first_day($syear, $smonth))."' AND '".$db->idate(dol_get_last_day($syear, $smonth))."'";
elseif ($syear && $smonth && $sday)   $sql.= " AND dateo BETWEEN '".$db->idate(dol_mktime(0, 0, 0, $smonth, $sday, $syear))."' AND '".$db->idate(dol_mktime(23, 59, 59, $smonth, $sday, $syear))."'";
else dol_print_error('', 'Year not defined');
// Define filter on bank account
$sql.=" AND (b.fk_account = ".((int) $conf->global->CASHDESK_ID_BANKACCOUNT_CASH);
$sql.=" OR b.fk_account = ".((int) $conf->global->CASHDESK_ID_BANKACCOUNT_CB);
$sql.=" OR b.fk_account = ".((int) $conf->global->CASHDESK_ID_BANKACCOUNT_CHEQUE);
$sql.=")";
*/
$sql = "SELECT f.rowid as facid, f.ref, f.datef as do, pf.amount as amount, b.fk_account as bankid, cp.code";
$sql .= " FROM " . MAIN_DB_PREFIX . "paiement_facture as pf, " . MAIN_DB_PREFIX . "facture as f, " . MAIN_DB_PREFIX . "paiement as p, " . MAIN_DB_PREFIX . "c_paiement as cp, " . MAIN_DB_PREFIX . "bank as b";
$sql .= " WHERE pf.fk_facture = f.rowid AND p.rowid = pf.fk_paiement AND cp.id = p.fk_paiement AND p.fk_bank = b.rowid";
$sql .= " AND f.module_source = '" . $db->escape($posmodule) . "'";
$sql .= " AND f.pos_source = '" . $db->escape($terminalid) . "'";
$sql .= " AND f.paye = 1";
$sql .= " AND p.entity = " . $conf->entity; // Never share entities for features related to accountancy
/*if ($key == 'cash')       $sql.=" AND cp.code = 'LIQ'";
elseif ($key == 'cheque') $sql.=" AND cp.code = 'CHQ'";
elseif ($key == 'card')   $sql.=" AND cp.code = 'CB'";
else
{
	dol_print_error('Value for key = '.$key.' not supported');
	exit;
}*/
if ($syear && !$smonth) {
    $sql .= " AND datef BETWEEN '" . $db->idate(dol_get_first_day($syear, 1)) . "' AND '" . $db->idate(dol_get_last_day($syear, 12)) . "'";
} elseif ($syear && $smonth && !$sday) {
    $sql .= " AND datef BETWEEN '" . $db->idate(dol_get_first_day($syear, $smonth)) . "' AND '" . $db->idate(dol_get_last_day($syear, $smonth)) . "'";
} elseif ($syear && $smonth && $sday) {
    $sql .= " AND datef BETWEEN '" . $db->idate(dol_mktime(0, 0, 0, $smonth, $sday, $syear)) . "' AND '" . $db->idate(dol_mktime(23, 59, 59, $smonth, $sday, $syear)) . "'";
} else {
    dol_print_error('', 'Year not defined');
}
$resql = $db->query($sql);
if ($resql) {
    $num = $db->num_rows($resql);
    $num2 = $db->num_rows($resql2);
    $i = 0;

    print "<!-- title of cash fence -->\n";
    print '<center>';
    print '<h2>';
    if ($object->status != $object::STATUS_DRAFT) {
        print $langs->trans("CashControl_Z") . " - " . $object->id;
    } else {
        print $langs->trans("CashControl_Z") . " - " . $langs->trans("Draft");
    }
    print "<br />";
    print "<u>" . $langs->trans("RAPPORT_(RAZ)") . "</u>";
    print "</h2>";
    print $mysoc->name;
    $userauthor = $object->fk_user_valid;
    if (empty($userauthor)) {
        $userauthor = $object->fk_user_creat;
    }

    $uservalid = new User($db);
    if ($userauthor > 0) {
        $uservalid->fetch($userauthor);
        print '<br>' . $langs->trans("Author") . ': ' . $uservalid->getFullName($langs);
    }
    print '<br>' . $langs->trans("pdvName") . ": Terminal " . $object->posnumber;
    print '<br>' . $langs->trans("Period") . ': ';
    print '<br>';
    print '    Du : ' . dol_print_date($object->date_creation, 'dayhour');
    print '<br>';
    print '    au: ' . dol_print_date($object->date_valid, 'dayhour');
    print '</center>';

    require_once DOL_DOCUMENT_ROOT . '/categories/class/categorie.class.php';
    $old_id = 0;
    $distint_ref = 0;
    $invoicetmp = new Facture($db);
    $array_res = array();
    $array_res["CA_TOTAL"] = 0;
    $array_res["CATEG"] = array();

    while ($objp = $db->fetch_object($resql)) {
        if ($objp->facid != $old_id){
            $distint_ref ++;
            $old_id = $objp->facid;
            $invoicetmp->fetch($objp->facid);
            $array_res["CA_TOTAL"] += $invoicetmp->total_ht;
            foreach ($invoicetmp->lines as $val) {
                $c = new Categorie($db);
                $cats = $c->containing($val->fk_product, Categorie::TYPE_PRODUCT);
                $array_res["CATEG"][$cats[0]->id]["NB"] += $val->qty;
                $array_res["CATEG"][$cats[0]->id]["HT"] += $val->total_ht;
                $array_res["CATEG"][$cats[0]->id]["TTC"] += $val->total_ttc;
                $array_res["CATEG"][$cats[0]->id]["TVA"] += $val->total_tva;
                $array_res["TVA_VENTILLATION"][$val->tva_tx]["HT"] += $val->total_ht;
                $array_res["TVA_VENTILLATION"][$val->tva_tx]["TTC"] += $val->total_ttc;
                $array_res["TVA_VENTILLATION"][$val->tva_tx]["TVA"] += $val->total_tva;
                $array_res["PRODUCT_QTY"][$val->fk_product]["QTY"] += $val->qty;
                $array_res["PRODUCT_QTY"][$val->fk_product]["TTC"] += $val->total_ttc;
                $array_res["PRODUCT_QTY"][$val->fk_product]["TVA"] += $val->total_tva;
                $array_res["PRODUCT_QTY"][$val->fk_product]["HT"] += $val->total_ht;
            }
        }
        $array_res["PaymentMode"][$objp->code]["TTC"] += $objp->amount;
    }

    $array_res["NB_VENTE"] = $distint_ref;

    print "<div style='text-align: left'>";
    print '<br>' . $langs->trans("CA_TOTAL") . ': ' . price($array_res["CA_TOTAL"]);
    print '<br>' . $langs->trans("NB_VENTE") . ': ' . $array_res["NB_VENTE"];
    if ($array_res["NB_VENTE"] > 1){
        print '<br>' . $langs->trans("MOY_TICKET") . ': ' . price($array_res["CA_TOTAL"] /  $array_res["NB_VENTE"]);
    }elseif($array_res["NB_VENTE"] > 0){
        print '<br>' . $langs->trans("MOY_TICKET") . ': ' . price($array_res["CA_TOTAL"]);
    }
    print "</div>";

    print "<div style='text-align: left'><h2>";
    print $langs->trans("FAMILLE_DETAIL");
    print "</h2></div>";

    print '<div class="div-table-responsive">';
    print '<table class="tagtable liste">' . "\n";

    $param = '';

    // Fields title
    print '<tr class="liste_titre">';
    print_liste_field_titre($arrayfields['p.categ']['label'], $_SERVER['PHP_SELF'], 'p.categ', '', $param, '', $sortfield, $sortorder);
    print_liste_field_titre($arrayfields['c.nbr']['label'], $_SERVER['PHP_SELF'], 'c.nbr', '', $param, '"', $sortfield, $sortorder);
    print_liste_field_titre($arrayfields['c.HT']['label'], $_SERVER['PHP_SELF'], 'c.HT', '', $param, '', $sortfield, $sortorder);
    print_liste_field_titre($arrayfields['c.tva']['label'], $_SERVER['PHP_SELF'], 'c.tva', '', $param, '', $sortfield, $sortorder);
    print_liste_field_titre($arrayfields['c.ttc']['label'], $_SERVER['PHP_SELF'], 'c.ttc', '', $param, '', $sortfield, $sortorder);
    print "</tr>\n";

    // Loop on each record
    $cash = $bank = $cheque = $other = 0;
    $totalqty = 0;
    $totalvat = 0;
    $totalvatperrate = array();
    $totallocaltax1 = 0;
    $totallocaltax2 = 0;
    $cachebankaccount = array();
    $cacheinvoiceid = array();
    $transactionspertype = array();
    $amountpertype = array();
    $totalarray = array();
    foreach ($array_res["CATEG"] as $key => $val) {
        $categories = new Categorie($db);
        $categories->fetch($array_res["CATEG"]);
        $sql = "SELECT label FROM " . MAIN_DB_PREFIX . "categorie where rowid = " . $key;
        $resLabel = $db->query($sql);
        if (!empty($resLabel->num_rows)) {
            $res = $db->fetch_object($resLabel);
            print '<tr class="oddeven">';
            // TAG/CATEG
            print '<td class="nowrap left">';
            print $res->label;
            print '</td>';
            if (!$i) {
                $totalarray['nbfield']++;
            }

            // NB Produits
            print '<td class="nowrap left">';
            print $val["NB"];
            print "</td>\n";
            if (!$i) {
                $totalarray['nbfield']++;
            }
            // HT
            print '<td class="nowrap left">';
            print price($val["HT"]);
            print "</td>\n";
            $totalarray['ht'] += $val["HT"];

            if (!$i) {
                $totalarray['nbfield']++;
            }
            // VAT
            print '<td class="nowrap left">';
            print price($val["TVA"]);
            print "</td>\n";
            if (!$i) {
                $totalarray['nbfield']++;
            }
            // TTC
            print '<td class="nowrap left">';
            print price($val["TTC"]);
            print "</td>\n";
            if (!$i) {
                $totalarray['nbfield']++;
            }
            $totalarray['tot'] += $val["TTC"];
            print "</tr>";
        }
    }


    print '<div class="div-table-responsive">';
    print '<table class="tagtable liste">' . "\n";
    print '<tr class="liste_total">';
    print '<td>' . $langs->trans("Total") . '</td>';
    print '<td class="left">' . price($totalarray['ht']) . ' HT</td>';
    print '<td class="right">' . price($totalarray['tot']) . ' TTC</td>';
    print '</tr>';
    print "</table>";
    print "</div>";

    print "<div style='text-align: left'><h2>";
    print $langs->trans("ENCAISSEMENT_DETAIL");
    print "</h2></div>";

    print '<div class="div-table-responsive">';
    print '<table class="tagtable liste">' . "\n";

    $param = '';

    // Fields title
    print '<tr class="liste_titre">';
    print_liste_field_titre($langs->trans("PaymentMode"), $_SERVER['PHP_SELF'], 'p.payement', '', $param, '', $sortfield, $sortorder);
    print_liste_field_titre("", $_SERVER['PHP_SELF'], 'c.HT', '', $param, '', $sortfield, $sortorder);
    print_liste_field_titre("", $_SERVER['PHP_SELF'], 'c.tva', '', $param, '', $sortfield, $sortorder);
    print_liste_field_titre($langs->trans("SellingPrice_TTC"), $_SERVER['PHP_SELF'], 'c.ttc', '', $param, '', $sortfield, $sortorder);
    print "</tr>\n";

    // Loop on each record
    $cash = $bank = $cheque = $other = 0;
    $totalqty = 0;
    $totalvat = 0;
    $totalvatperrate = array();
    $totallocaltax1 = 0;
    $totallocaltax2 = 0;
    $cachebankaccount = array();
    $cacheinvoiceid = array();
    $transactionspertype = array();
    $amountpertype = array();
    $totalarray = array();
    foreach ((array)$array_res["PaymentMode"] as $key => $val) {
        $categories = new Categorie($db);
        $categories->fetch($array_res["CATEG"]);
        $sql = "SELECT libelle FROM " . MAIN_DB_PREFIX . "c_paiement where code = '" . $key . "'";
        $resLabel = $db->query($sql);
        if (!empty($resLabel->num_rows)) {
            $res = $db->fetch_object($resLabel);
            print '<tr class="oddeven">';
            // TAG/CATEG
            print '<td class="nowrap left">';
            print $res->libelle;
            print '</td>';
            if (!$i) {
                $totalarray['nbfield']++;
            }

            // HT
            print '<td class="nowrap left">';
//            print price($val["HT"]);
            print "</td>\n";
            $totalarray['ht'] += $val["HT"];
            if (!$i) {
                $totalarray['nbfield']++;
            }
            // VAT
            print '<td class="nowrap left">';
//            print price($val["TVA"]);
            print "</td>\n";
            if (!$i) {
                $totalarray['nbfield']++;
            }
            // TTC
            print '<td class="nowrap left">';
            print price($val["TTC"]);
            $totalarray["ttc"] += $val["TTC"];
            print "</td>\n";
            if (!$i) {
                $totalarray['nbfield']++;
            }
            print "</tr>";
        }
    }


    print '<div class="div-table-responsive">';
    print '<table class="tagtable liste">' . "\n";
    print '<tr class="liste_total">';
    print '<td>' . $langs->trans("Total") . '</td>';
//    print '<td class="left">' . price($totalarray['ht']) . ' HT</td>';
    print '<td class="right">' . price($totalarray['ttc']) . ' TTC</td>';
    print '</tr>';
    print "</table>";
    print "</div>";


    print "<div style='text-align: left'><h2>";
    print $langs->trans("TVA_VENTILLATION");
    print "</h2></div>";

    print '<div class="div-table-responsive">';
    print '<table class="tagtable liste">' . "\n";

    $param = '';

    // Fields title
    print '<tr class="liste_titre">';
    print_liste_field_titre($langs->trans("TXTVA"), $_SERVER['PHP_SELF'], 'p.payement', '', $param, '', $sortfield, $sortorder);
    print_liste_field_titre($langs->trans("HT"), $_SERVER['PHP_SELF'], 'c.HT', '', $param, '', $sortfield, $sortorder);
    print_liste_field_titre($langs->trans("TVA"), $_SERVER['PHP_SELF'], 'c.tva', '', $param, '', $sortfield, $sortorder);
    print_liste_field_titre($langs->trans("SellingPrice_TTC"), $_SERVER['PHP_SELF'], 'c.ttc', '', $param, '', $sortfield, $sortorder);
    print "</tr>\n";

    // Loop on each record
    $cash = $bank = $cheque = $other = 0;
    $totalqty = 0;
    $totalvat = 0;
    $totalvatperrate = array();
    $totallocaltax1 = 0;
    $totallocaltax2 = 0;
    $cachebankaccount = array();
    $cacheinvoiceid = array();
    $transactionspertype = array();
    $amountpertype = array();
    $totalarray = array();
    foreach ((array)$array_res["TVA_VENTILLATION"] as $key => $val) {
        print '<tr class="oddeven">';
        // TAG/CATEG
        print '<td class="nowrap left">';
        print round($key, 2) . " %";
        print '</td>';
        if (!$i) {
            $totalarray['nbfield']++;
        }

        // HT
        print '<td class="nowrap left">';
        print price($val["HT"]);
        print "</td>\n";
        $totalarray['ht'] += $val["HT"];
        if (!$i) {
            $totalarray['nbfield']++;
        }
        // VAT
        print '<td class="nowrap left">';
        print price($val["TVA"]);
        print "</td>\n";
        if (!$i) {
            $totalarray['nbfield']++;
        }
        // TTC
        print '<td class="nowrap left">';
        print price($val["TTC"]);
        $totalarray["ttc"] += $val["TTC"];
        print "</td>\n";
        if (!$i) {
            $totalarray['nbfield']++;
        }
        print "</tr>";
    }


    print '<div class="div-table-responsive">';
    print '<table class="tagtable liste">' . "\n";
    print '<tr class="liste_total">';
    print '<td>' . $langs->trans("Total") . '</td>';
    print '<td class="left">' . price($totalarray['ht']) . ' HT</td>';
    print '<td class="right">' . price($totalarray['ttc']) . ' TTC</td>';
    print '</tr>';
    print "</table>";
    print "</div>";

    print "<div style='text-align: left'><h2>";
    print $langs->trans("TICKET_RECAPITULATIF_DES_VENTES_PAR_PRODUITS");
    print "</h2></div>";

    print '<div class="">';
    print '<table class="tagtable liste">' . "\n";

    $param = '';

    // Fields title
    print '<tr class="liste_titre">';
    print_liste_field_titre($langs->trans("PROD"), $_SERVER['PHP_SELF'], 'p.payement', '', $param, '', $sortfield, $sortorder);
    print_liste_field_titre($langs->trans("PROD_QTY"), $_SERVER['PHP_SELF'], 'p.payement', '', $param, '', $sortfield, $sortorder);
    print_liste_field_titre($langs->trans("HT"), $_SERVER['PHP_SELF'], 'c.HT', '', $param, '', $sortfield, $sortorder);
    print_liste_field_titre($langs->trans("TVA"), $_SERVER['PHP_SELF'], 'c.tva', '', $param, '', $sortfield, $sortorder);
    print_liste_field_titre($langs->trans("TTC"), $_SERVER['PHP_SELF'], 'c.ttc', '', $param, '', $sortfield, $sortorder);
    print "</tr>\n";
    // Loop on each record
    $cash = $bank = $cheque = $other = 0;
    $totalqty = 0;
    $totalvat = 0;
    $totalvatperrate = array();
    $totallocaltax1 = 0;
    $totallocaltax2 = 0;
    $cachebankaccount = array();
    $cacheinvoiceid = array();
    $transactionspertype = array();
    $amountpertype = array();
    $totalarray = array();
    $object_product = new Product($db);
    foreach ((array)$array_res["PRODUCT_QTY"] as $key => $val) {
        print '<tr class="oddeven">';
        // TAG/CATEG
        $object_product->fetch($key);
        print '<td class="nowrap left">';
        print $object_product->label;
        print '</td>';
        if (!$i) {
            $totalarray['nbfield']++;
        }
        // QTY
        print '<td class="nowrap left">';
        print $val["QTY"];
        print "</td>\n";
        $totalarray['qty'] += $val["QTY"];
        if (!$i) {
            $totalarray['nbfield']++;
        }
        // HT
        print '<td class="nowrap left">';
        print price($val["HT"]);
        print "</td>\n";
        $totalarray['ht'] += $val["HT"];
        if (!$i) {
            $totalarray['nbfield']++;
        }
        // VAT
        print '<td class="nowrap left">';
        print price($val["TVA"]);
        print "</td>\n";
        if (!$i) {
            $totalarray['nbfield']++;
        }
        // TTC
        print '<td class="nowrap left">';
        print price($val["TTC"]);
        $totalarray["ttc"] += $val["TTC"];
        print "</td>\n";
        if (!$i) {
            $totalarray['nbfield']++;
        }
        print "</tr>";
    }

    print '<div class="div-table-responsive">';
    print '<table class="tagtable liste">' . "\n";
    print '<tr class="liste_total">';
    print '<td>' . $langs->trans("Total") . '</td>';

    print '<td colspan="2">' . $totalarray['qty'] . ' ' . $langs->trans("PROD_QTY") . '</td>';
    print '<td colspan="2"></td>';
    print '<td colspan="2">' . price($totalarray['ht']) . ' HT</td>';
    print '<td colspan="2"></td>';
    print '<td colspan="2">' . price($totalarray['ttc']) . ' TTC</td>';
    print '</tr>';
    print "</table>";
    print "</div>";


    print '</form>';

    $db->free($resql);
} else {
    dol_print_error($db);
}

llxFooter();

$db->close();
